@@ -1,21 +1,8 @@
-// Main - Main functions
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 #ifdef __BORLANDC__
@@ -30,7 +17,7 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-const MediaInfoNameSpace::Char* MEDIAINFO_TITLE=__T("MediaInfo - http://mediainfo.sourceforge.net");
+const MediaInfoNameSpace::Char* MEDIAINFO_TITLE=__T("MediaArea.net/MediaInfo");
 ZenLib::Ztring Text_Temp;
 using namespace ZenLib;
 //---------------------------------------------------------------------------
@@ -59,7 +46,7 @@ Core::~Core()
 void Core::Data_Prepare()
 {
     //Inform
-    Text=MI->Inform((size_t)-1).c_str();
+    Text=MI->Inform((size_t)-1);
 }
 
 //***************************************************************************
@@ -177,9 +164,11 @@ size_t Core::Menu_File_Open_Files_Continue (const String &FileName)
     //MI->Option(__T("LegacyStreamDisplay"), __T("0"));
     //MI->Option(__T("File_MpegTs_Atsc_transport_stream_id_Trust"), __T("0"));
     //MI->Option(__T("Trace_Level"), __T("Container1;1"));
-    //MI->Option(__T("Language"), __T("raw"));
+    //MI->Option(__T("File_Mxf_TimeCodeFromMaterialPackage"), __T("1"));
     //MI->Option(__T("demux"), __T("container"));
     //MI->Option(__T("file_demux_unpacketize"), __T("1"));
+    //MI->Option(__T("Language"), __T("raw"));
+    //MI->Option(__T("Inform"), __T("PBCore2"));
     return MI->Open(FileName);
 }
 
@@ -213,6 +202,15 @@ void Core::Menu_View_Tree ()
         Menu_Debug_Details(Details);
 }
 
+//---------------------------------------------------------------------------
+void Core::Menu_View_Text()
+{
+    MI->Option(__T("Inform"), String());
+    Kind = Kind_Text;
+    if (Details>0)
+        Menu_Debug_Details(Details);
+}
+
 //---------------------------------------------------------------------------
 void Core::Menu_View_HTML ()
 {
@@ -235,10 +233,10 @@ void Core::Menu_View_PBCore ()
 }
 
 //---------------------------------------------------------------------------
-void Core::Menu_View_reVTMD ()
+void Core::Menu_View_PBCore2 ()
 {
-    MI->Option(__T("Inform"), __T("reVTMD"));
-    Kind=Kind_reVTMD;
+    MI->Option(__T("Inform"), __T("PBCore2"));
+    Kind=Kind_PBCore2;
 }
 
 //---------------------------------------------------------------------------
@@ -249,12 +247,45 @@ void Core::Menu_View_MPEG7 ()
 }
 
 //---------------------------------------------------------------------------
-void Core::Menu_View_Text ()
+void Core::Menu_View_EBUCore_1_5 ()
 {
-    MI->Option(__T("Inform"), String());
-    Kind=Kind_Text;
-    if (Details>0)
-        Menu_Debug_Details(Details);
+    MI->Option(__T("Inform"), __T("EBUCore_1.5"));
+    Kind=Kind_EBUCore_1_4;
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_EBUCore_1_6()
+{
+    MI->Option(__T("Inform"), __T("EBUCore_1.6"));
+    Kind = Kind_EBUCore_1_4;
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_FIMS_1_1 ()
+{
+    MI->Option(__T("Inform"), __T("FIMS_1.1"));
+    Kind=Kind_FIMS_1_1;
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_FIMS_1_2 ()
+{
+    MI->Option(__T("Inform"), __T("FIMS_1.2"));
+    Kind=Kind_FIMS_1_2;
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_FIMS_1_3 ()
+{
+    MI->Option(__T("Inform"), __T("FIMS_1.3"));
+    Kind=Kind_FIMS_1_3;
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_reVTMD()
+{
+    MI->Option(__T("Inform"), __T("reVTMD"));
+    Kind = Kind_reVTMD;
 }
 
 //---------------------------------------------------------------------------
@@ -320,6 +351,12 @@ void Core::Menu_Help_Info_Parameters ()
     Text=MI->Option(__T("Info_Parameters"));
 }
 
+//---------------------------------------------------------------------------
+void Core::Menu_Help_Info_CanHandleUrls()
+{
+    Text=MI->Option(__T("Info_CanHandleUrls"));
+}
+
 //---------------------------------------------------------------------------
 void Core::Menu_Language (const String& Language)
 {
@@ -334,7 +371,7 @@ void Core::Menu_Language (const String& Language)
 String& Core::Inform_Get ()
 {
     if (Text_Temp.empty())
-        Text=MI->Inform((size_t)-1).c_str();
+        Text=MI->Inform((size_t)-1);
     else
         Text=Text_Temp;
     return Text;
@@ -350,7 +387,7 @@ Core::kind Core::Kind_Get ()
 String Core::Inform_Get(size_t Pos, stream_t StreamKind, size_t StreamPos)
 {
     MI->Option(__T("Inform"), String());
-    return MI->Get(Pos, StreamKind, StreamPos, __T("Inform")).c_str();
+    return MI->Get(Pos, StreamKind, StreamPos, __T("Inform"));
 }
 
 // Accessors
@@ -368,7 +405,7 @@ size_t Core::Count_Get(size_t File_Pos, stream_t StreamKind, size_t StreamNumber
 String Core::Summary_Get(int File_Pos, stream_t StreamKind, size_t StreamPos)
 {
     MI->Option(__T("Inform"), __T("Summary"));
-    return MI->Get(File_Pos, StreamKind, StreamPos, __T("Inform")).c_str();
+    return MI->Get(File_Pos, StreamKind, StreamPos, __T("Inform"));
 }
 
 //---------------------------------------------------------------------------
