@@ -473,7 +473,9 @@ int Preferences::ExplorerShell()
     List=__T(
         ".264;H264File\r\n"
         ".3g2;mpeg4File\r\n"
+	".3ga;mpeg4File\r\n"    
         ".3gp;mpeg4File\r\n"
+	".3gpa;mpeg4File\r\n"
         ".3gpp;mpeg4File\r\n"
         ".aac;AACFile\r\n"
         ".ac3;AC3File\r\n"
@@ -522,6 +524,7 @@ int Preferences::ExplorerShell()
         ".m4b;mpeg4File\r\n"
         ".m4v;mpeg4File\r\n"
         ".mac;APEFile\r\n"
+        ".mk3d;MK3DFile\r\n"
         ".mka;MKAFile\r\n"
         ".mks;MKSFile\r\n"
         ".mkv;MKVFile\r\n"
@@ -559,6 +562,8 @@ int Preferences::ExplorerShell()
         ".stl;STLFile\r\n"
         ".swf;FlashFile\r\n"
         ".tak;TakVideoFile\r\n"
+	".tif;TIFFFile\r\n"
+	".tiff;TIFFFile\r\n"
         ".tp;TPFile\r\n"
         ".trp;TRPFile\r\n"
         ".ts;tsFile\r\n"
@@ -1061,7 +1066,9 @@ int Preferences::ShellToolTip()
     List=__T(
         ".264;H264File\r\n"
         ".3g2;mpeg4File\r\n"
+	".3ga;mpeg4File\r\n"
         ".3gp;mpeg4File\r\n"
+	".3gpa;mpeg4File\r\n"
         ".3gpp;mpeg4File\r\n"
         ".aac;AACFile\r\n"
         ".ac3;AC3File\r\n"
@@ -1111,6 +1118,7 @@ int Preferences::ShellToolTip()
         ".m4v;mpeg4File\r\n"
         ".mac;APEFile\r\n"
         ".mlp;MLPFile\r\n"
+        ".mk3d;MK3DFile\r\n"
         ".mka;MKAFile\r\n"
         ".mks;MKSFile\r\n"
         ".mkv;MKVFile\r\n"
@@ -1147,6 +1155,8 @@ int Preferences::ShellToolTip()
         ".stl;STLFile\r\n"
         ".swf;FlashFile\r\n"
         ".tak;TAKFile\r\n"
+	".tif;TIFFFile\r\n"
+	".tiff;TIFFFile\r\n"
         ".tp;TPFile\r\n"
         ".trp;TRPFile\r\n"
         ".ts;tsFile\r\n"
