@@ -1,21 +1,8 @@
-// File_Pcm - Info for PCM files
-// Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -48,7 +35,7 @@ namespace MediaInfoLib
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-const char* Smpte_St0302_ChannelsPositions(int8u Channels)
+static const char* Smpte_St0302_ChannelsPositions(int8u Channels)
 {
     switch (Channels)
     {
@@ -61,7 +48,7 @@ const char* Smpte_St0302_ChannelsPositions(int8u Channels)
 }
 
 //---------------------------------------------------------------------------
-const char* Smpte_St0302_ChannelsPositions2(int8u Channels)
+static const char* Smpte_St0302_ChannelsPositions2(int8u Channels)
 {
     switch (Channels)
     {
@@ -81,7 +68,11 @@ const char* Smpte_St0302_ChannelsPositions2(int8u Channels)
 File_Pcm::File_Pcm()
 {
     //Configuration
-    ParserName=__T("PCM");
+    ParserName="PCM";
+    #if MEDIAINFO_EVENTS
+        ParserIDs[0]=MediaInfo_Parser_Pcm;
+        StreamIDs_Width[0]=0;
+    #endif //MEDIAINFO_EVENTS
     #if MEDIAINFO_TRACE
         Trace_Layers_Update(8); //Stream
     #endif //MEDIAINFO_TRACE
@@ -89,8 +80,9 @@ File_Pcm::File_Pcm()
     PTS_DTS_Needed=true;
 
     //In
-    Frame_Count_Valid=2;
+    Frame_Count_Valid=4;
     BitDepth=0;
+    BitDepth_Significant=0;
     Channels=0;
     SamplingRate=0;
     Endianness='\0';
@@ -222,7 +214,12 @@ void File_Pcm::Streams_Fill()
     Fill(Stream_Audio, 0, Audio_Codec_Settings_ITU, ITU);
 
     //BitDepth
-    if (BitDepth)
+    if (BitDepth_Significant)
+    {
+        Fill(Stream_Audio, 0, Audio_BitDepth, BitDepth_Significant);
+        Fill(Stream_Audio, 0, Audio_BitDepth_Stored, BitDepth);
+    }
+    else if (BitDepth)
         Fill(Stream_Audio, 0, Audio_BitDepth, BitDepth);
 
     //Channels
@@ -249,6 +246,36 @@ void File_Pcm::Streams_Finish()
     Frame_Count_NotParsedIncluded=(int64u)-1;
 }
 
+//***************************************************************************
+// Buffer - Global
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+void File_Pcm::Read_Buffer_Continue()
+{
+    #if MEDIAINFO_DEMUX
+        if (Demux_UnpacketizeContainer && !Frame_Count && !Status[IsAccepted])
+        {
+            if (Demux_Items.size()<Frame_Count_Valid)
+            {
+                demux_item Item;
+                Item.DTS=FrameInfo_Next.Buffer_Offset_End!=(int64u)-1?FrameInfo_Next.DTS:FrameInfo.DTS;
+                Item.DUR=FrameInfo_Next.Buffer_Offset_End!=(int64u)-1?FrameInfo_Next.DUR:FrameInfo.DUR;
+                Item.Size=Buffer_Size;
+                for (size_t i=0; i<Demux_Items.size(); i++)
+                    Item.Size-=Demux_Items[i].Size;
+                Demux_Items.push_back(Item);
+            }
+            if (Demux_Items.size()<Frame_Count_Valid)
+            {
+                Element_WaitForMoreData();
+                return;
+            }
+            Accept();
+        }
+    #endif //MEDIAINFO_DEMUX
+}
+
 //***************************************************************************
 // Buffer - File header
 //***************************************************************************
@@ -265,19 +292,6 @@ bool File_Pcm::FileHeader_Begin()
     return true;
 }
 
-//***************************************************************************
-// Buffer - Global
-//***************************************************************************
-
-//---------------------------------------------------------------------------
-#if MEDIAINFO_DEMUX
-void File_Pcm::Read_Buffer_Continue()
-{
-    if (Demux_UnpacketizeContainer && !Status[IsAccepted] && Buffer_Size && Frame_Count_Valid && Frame_Count+1>=Frame_Count_Valid)
-        Accept();
-}
-#endif //MEDIAINFO_DEMUX
-
 //***************************************************************************
 // Buffer - Per element
 //***************************************************************************
@@ -287,6 +301,18 @@ void File_Pcm::Header_Parse()
 {
     //Filling
     Header_Fill_Code(0, "Block");
+    #if MEDIAINFO_DEMUX
+        if (!Demux_Items.empty())
+        {
+            FrameInfo.DTS=Demux_Items[0].DTS;
+            FrameInfo.DUR=Demux_Items[0].DUR;
+            Element_Size=Demux_Items[0].Size;
+            if (Frame_Count_NotParsedIncluded!=(int64u)-1 && Frame_Count_NotParsedIncluded>=Demux_Items.size()-1)
+                Frame_Count_NotParsedIncluded-=Demux_Items.size()-1;
+            Demux_Items.pop_front();
+        }
+    #endif MEDIAINFO_DEMUX
+
     if (BitDepth && Channels)
     {
         int64u Size=(Element_Size/(BitDepth*Channels/8))*(BitDepth*Channels/8); //A complete sample
@@ -374,7 +400,25 @@ void File_Pcm::Data_Parse()
     //Parsing
     Skip_XX(Element_Size,                                       "Data"); //It is impossible to detect... Default is no detection, only filling
 
-    Frame_Count++;
+    {
+        if (BitDepth && Channels && SamplingRate)
+            FrameInfo.DUR=Element_Size*1000000000*8/BitDepth/Channels/SamplingRate;
+        if (FrameInfo.DUR!=(int64u)-1)
+        {
+            if (FrameInfo.DTS!=(int64u)-1)
+                FrameInfo.DTS+=FrameInfo.DUR;
+            if (FrameInfo.PTS!=(int64u)-1)
+                FrameInfo.PTS+=FrameInfo.DUR;
+        }
+        else
+        {
+            FrameInfo.DTS=(int64u)-1;
+            FrameInfo.PTS=(int64u)-1;
+        }
+        Frame_Count++;
+        if (Frame_Count_NotParsedIncluded!=(int64u)-1)
+            Frame_Count_NotParsedIncluded++;
+    }
     if ((!Status[IsAccepted] && Frame_Count>=Frame_Count_Valid) || File_Offset+Buffer_Size>=File_Size)
     {
         Accept();
