@@ -1,21 +1,8 @@
-// File_SmpteSt0337 - Info about SMPTE ST 337 stream
-// Copyright (C) 2008-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -53,6 +40,7 @@
 #if MEDIAINFO_SEEK
     #include "MediaInfo/MediaInfo_Internal.h"
 #endif // MEDIAINFO_SEEK
+#include "MediaInfo/File_Unknown.h"
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -63,7 +51,7 @@ namespace MediaInfoLib
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-const char* Smpte_St0337_data_type[32]= // SMPTE ST 338
+static const char* Smpte_St0337_data_type[32]= // SMPTE ST 338
 {
     "",
     "AC-3",
@@ -100,7 +88,7 @@ const char* Smpte_St0337_data_type[32]= // SMPTE ST 338
 };
 
 //---------------------------------------------------------------------------
-stream_t Smpte_St0337_data_type_StreamKind[32]= // SMPTE 338M
+static stream_t Smpte_St0337_data_type_StreamKind[32]= // SMPTE 338M
 {
     Stream_Max,
     Stream_Audio,
@@ -149,18 +137,21 @@ File_SmpteSt0337::File_SmpteSt0337()
         ParserIDs[0]=MediaInfo_Parser_Aes3;
     #endif // MEDIAINFO_EVENTS
     MustSynchronize=true;
-    Buffer_TotalBytes_FirstSynched_Max=32*1024;
+    Buffer_TotalBytes_FirstSynched_Max=256*1024;
     PTS_DTS_Needed=true;
 
     // In
     Container_Bits=0;
     Endianness=0x00;
+    Aligned=false;
 
     // Temp
     FrameRate=0;
     Stream_Bits=0;
     data_type=(int8u)-1;
     GuardBand_Before=0;
+    GuardBand_After=0;
+    NullPadding_Size=0;
 
     // Parser
     Parser=NULL;
@@ -183,7 +174,7 @@ File_SmpteSt0337::~File_SmpteSt0337()
 //---------------------------------------------------------------------------
 void File_SmpteSt0337::Streams_Accept()
 {
-    Fill(Stream_General, 0, General_Format, "AES3");
+    Fill(Stream_General, 0, General_Format, "SMPTE ST 337");
     Fill(Stream_General, 0, General_OverallBitRate_Mode, "CBR");
 }
 
@@ -247,7 +238,8 @@ void File_SmpteSt0337::Streams_Fill()
         if (Retrieve(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitDepth)).empty())
             Fill(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitDepth), Stream_Bits);
 
-        Fill(StreamKind_Last, Pos, "MuxingMode", "AES3");
+        if (IsSub)
+            Fill(StreamKind_Last, Pos, "MuxingMode", "SMPTE ST 337");
         if (Retrieve(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitRate_Mode))!=__T("CBR"))
             Fill(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitRate_Mode), "CBR");
         if (File_Size!=(int64u)-1 && FrameSizes.size()==1)
@@ -267,7 +259,7 @@ void File_SmpteSt0337::Read_Buffer_Unsynched()
 {
     if (Frame_Count_NotParsedIncluded!=(int64u)-1 && FrameRate)
     {
-        Frame_Count_NotParsedIncluded=File_GoTo/FrameRate;
+        Frame_Count_NotParsedIncluded=float64_int64s(File_GoTo/FrameRate);
         FrameInfo.DTS=Frame_Count_NotParsedIncluded*1000000000/48000;
     }
 }
@@ -292,7 +284,7 @@ size_t File_SmpteSt0337::Read_Buffer_Seek (size_t Method, int64u Value, int64u I
         if (!MiOpenResult)
             return 0;
 
-        FrameRate=MI.Get(Stream_Audio, 0, __T("FrameCount")).To_int64u();
+        FrameRate=MI.Get(Stream_Audio, 0, __T("FrameRate")).To_float64();
 
         Duration_Detected=true;
     }
@@ -304,8 +296,8 @@ size_t File_SmpteSt0337::Read_Buffer_Seek (size_t Method, int64u Value, int64u I
                     if (FrameRate)
                     {
                         float64 FrameSize=3072000/FrameRate;
-                        int64u  FrameCount=Value/FrameSize;
-                        Value=(int64u)(FrameCount*FrameSize);
+                        int64u  FrameCount=float64_int64s(Value/FrameSize);
+                        Value=float64_int64s(FrameCount*FrameSize);
                     }
                     GoTo(Value);
                     Open_Buffer_Unsynch();
@@ -320,7 +312,7 @@ size_t File_SmpteSt0337::Read_Buffer_Seek (size_t Method, int64u Value, int64u I
                     {
                         float64 FrameSize=3072000/FrameRate;
                         Unsynch_Frame_Count=float64_int64s(((float64)Value)/1000000000*FrameRate);
-                        GoTo(Unsynch_Frame_Count*FrameSize);
+                        GoTo(float64_int64s(Unsynch_Frame_Count*FrameSize));
                         Open_Buffer_Unsynch();
                         return 1;
                     }
@@ -333,7 +325,7 @@ size_t File_SmpteSt0337::Read_Buffer_Seek (size_t Method, int64u Value, int64u I
                     {
                         float64 FrameSize=3072000/FrameRate;
                         Unsynch_Frame_Count=Value;
-                        GoTo(Unsynch_Frame_Count*FrameSize);
+                        GoTo(float64_int64s(Unsynch_Frame_Count*FrameSize));
                         Open_Buffer_Unsynch();
                         return 1;
                     }
@@ -362,7 +354,7 @@ bool File_SmpteSt0337::Synchronize()
             return false;
         }
 
-        if ((Container_Bits==0 || Container_Bits==16) && ((Buffer_TotalBytes+Buffer_Offset)%4)==0)
+        if ((Container_Bits==0 || Container_Bits==16) && (!Aligned || ((Buffer_TotalBytes+Buffer_Offset)%4)==0))
         {
             if (Buffer[Buffer_Offset  ]==0xF8
              && Buffer[Buffer_Offset+1]==0x72
@@ -385,7 +377,7 @@ bool File_SmpteSt0337::Synchronize()
                 break; // while()
             }
         }
-        if ((Container_Bits==0 || Container_Bits==20) && ((Buffer_TotalBytes+Buffer_Offset)%5)==0)
+        if ((Container_Bits==0 || Container_Bits==20) && (!Aligned || ((Buffer_TotalBytes+Buffer_Offset)%5)==0))
         {
             if (Buffer[Buffer_Offset  ]==0x6F
              && Buffer[Buffer_Offset+1]==0x87
@@ -399,7 +391,7 @@ bool File_SmpteSt0337::Synchronize()
                 break; // while()
             }
         }
-        if ((Container_Bits==0 || Container_Bits==20) && ((Buffer_TotalBytes+Buffer_Offset)%5)==0)
+        if ((Container_Bits==0 || Container_Bits==20) && (!Aligned || ((Buffer_TotalBytes+Buffer_Offset)%5)==0))
         {
             if (Buffer[Buffer_Offset  ]==0x72
              && Buffer[Buffer_Offset+1]==0xF8
@@ -413,7 +405,7 @@ bool File_SmpteSt0337::Synchronize()
                 break; // while()
             }
         }
-        if ((Container_Bits==0 || Container_Bits==24) && ((Buffer_TotalBytes+Buffer_Offset)%6)==0)
+        if ((Container_Bits==0 || Container_Bits==24) && (!Aligned || ((Buffer_TotalBytes+Buffer_Offset)%6)==0))
         {
             if (Buffer[Buffer_Offset  ]==0x96
              && Buffer[Buffer_Offset+1]==0xF8
@@ -432,7 +424,7 @@ bool File_SmpteSt0337::Synchronize()
              && Buffer[Buffer_Offset+2]==0x96
              && Buffer[Buffer_Offset+3]==0x1F
              && Buffer[Buffer_Offset+4]==0x4E
-             && Buffer[Buffer_Offset+5]==0x5A) // 24-bit, LE
+             && Buffer[Buffer_Offset+5]==0xA5) // 24-bit, LE
             {
                 Container_Bits=24;
                 Stream_Bits=24;
@@ -449,6 +441,7 @@ bool File_SmpteSt0337::Synchronize()
                 Container_Bits=24;
                 Stream_Bits=16;
                 Endianness='B'; // BE
+                NullPadding_Size=1;
                 break; // while()
             }
             if (Buffer[Buffer_Offset  ]==0x00
@@ -461,6 +454,7 @@ bool File_SmpteSt0337::Synchronize()
                 Container_Bits=24;
                 Stream_Bits=16;
                 Endianness='L'; // LE
+                NullPadding_Size=1;
                 break; // while()
             }
             if (Buffer[Buffer_Offset  ]==0x6F
@@ -488,7 +482,7 @@ bool File_SmpteSt0337::Synchronize()
                 break; // while()
             }
         }
-        if ((Container_Bits==0 || Container_Bits==32) && ((Buffer_TotalBytes+Buffer_Offset)%8)==0)
+        if ((Container_Bits==0 || Container_Bits==32) && (!Aligned || ((Buffer_TotalBytes+Buffer_Offset)%8)==0))
         {
             if (Buffer[Buffer_Offset  ]==0x00
              && Buffer[Buffer_Offset+1]==0x00
@@ -502,6 +496,7 @@ bool File_SmpteSt0337::Synchronize()
                 Container_Bits=32;
                 Stream_Bits=16;
                 Endianness='B'; // BE
+                NullPadding_Size=2;
                 break; // while()
             }
             if (Buffer[Buffer_Offset  ]==0x00
@@ -516,6 +511,7 @@ bool File_SmpteSt0337::Synchronize()
                 Container_Bits=32;
                 Stream_Bits=16;
                 Endianness='L'; // LE
+                NullPadding_Size=2;
                 break; // while()
             }
             if (Buffer[Buffer_Offset  ]==0x00
@@ -530,6 +526,7 @@ bool File_SmpteSt0337::Synchronize()
                 Container_Bits=32;
                 Stream_Bits=20;
                 Endianness='B'; // BE
+                NullPadding_Size=1;
                 break; // while()
             }
             if (Buffer[Buffer_Offset  ]==0x00
@@ -544,6 +541,7 @@ bool File_SmpteSt0337::Synchronize()
                 Container_Bits=32;
                 Stream_Bits=20;
                 Endianness='L'; // LE
+                NullPadding_Size=1;
                 break; // while()
             }
             if (Buffer[Buffer_Offset  ]==0x00
@@ -558,6 +556,7 @@ bool File_SmpteSt0337::Synchronize()
                 Container_Bits=32;
                 Stream_Bits=24;
                 Endianness='B'; // BE
+                NullPadding_Size=1;
                 break; // while()
             }
             if (Buffer[Buffer_Offset  ]==0x00
@@ -572,27 +571,38 @@ bool File_SmpteSt0337::Synchronize()
                 Container_Bits=32;
                 Stream_Bits=24;
                 Endianness='L'; // LE
+                NullPadding_Size=1;
                 break; // while()
             }
         }
 
-        if (Container_Bits)
+        if (Container_Bits>=4 && Aligned)
             Buffer_Offset+=Container_Bits/4;
         else
             Buffer_Offset++;
     }
 
-    // Guard band
-    GuardBand_Before+=Buffer_Offset-Buffer_Offset_Base;
-
     // Parsing last bytes if needed
     if (Buffer_Offset+16>Buffer_Size)
     {
+        if (!Status[IsAccepted])
+            GuardBand_Before+=Buffer_Offset;
         return false;
     }
 
     if (!Status[IsAccepted])
-        Accept("AES3");
+        Accept("SMPTE ST 337");
+
+    // Guard band
+    GuardBand_Before+=Buffer_Offset-Buffer_Offset_Base;
+    if (GuardBand_After)
+    {
+        if (GuardBand_Before>GuardBand_After)
+            GuardBand_Before-=GuardBand_After;
+        else
+            GuardBand_Before=0;
+        GuardBand_After=0;
+    }
 
     // Synched
     return true;
@@ -601,99 +611,115 @@ bool File_SmpteSt0337::Synchronize()
 //---------------------------------------------------------------------------
 bool File_SmpteSt0337::Synched_Test()
 {
+    // Guard band
+    size_t Buffer_Offset_Base=Buffer_Offset;
+
     // Skip NULL padding
     size_t Buffer_Offset_Temp=Buffer_Offset;
-    if (Container_Bits==16)
+    if (Aligned)
     {
-        while ((Buffer_TotalBytes+Buffer_Offset_Temp)%4) // Padding in part of the AES3 block
+        if (Container_Bits==16)
         {
-            if (Buffer_Offset_Temp+1>Buffer_Size)
+            while ((Buffer_TotalBytes+Buffer_Offset_Temp)%4) // Padding in part of the AES3 block
+            {
+                if (Buffer_Offset_Temp+1>Buffer_Size)
+                {
+                    Element_WaitForMoreData();
+                    return false;
+                }
+                if (Buffer[Buffer_Offset_Temp])
+                {
+                    Trusted_IsNot("Bad sync");
+                    return true;
+                }
+                Buffer_Offset_Temp++;
+            }
+            while(Buffer_Offset_Temp+4<=Buffer_Size && CC4(Buffer+Buffer_Offset_Temp)==0x00000000)
+                Buffer_Offset_Temp+=4;
+            if (Buffer_Offset_Temp+4>Buffer_Size)
             {
                 Element_WaitForMoreData();
                 return false;
             }
-            if (Buffer[Buffer_Offset_Temp])
-            {
-                Trusted_IsNot("Bad sync");
-                return true;
-            }
-            Buffer_Offset_Temp++;
         }
-        while(Buffer_Offset_Temp+4<=Buffer_Size && CC4(Buffer+Buffer_Offset_Temp)==0x00000000)
-            Buffer_Offset_Temp+=4;
-        if (Buffer_Offset_Temp+4>Buffer_Size)
+        if (Container_Bits==20)
         {
-            Element_WaitForMoreData();
-            return false;
+            while ((Buffer_TotalBytes+Buffer_Offset_Temp)%5) // Padding in part of the AES3 block
+            {
+                if (Buffer_Offset_Temp+1>Buffer_Size)
+                {
+                    Element_WaitForMoreData();
+                    return false;
+                }
+                if (Buffer[Buffer_Offset_Temp])
+                {
+                    Trusted_IsNot("Bad sync");
+                    return true;
+                }
+                Buffer_Offset_Temp++;
+            }
+            while(Buffer_Offset_Temp+5<=Buffer_Size && CC5(Buffer+Buffer_Offset_Temp)==0x0000000000LL)
+                Buffer_Offset_Temp+=5;
+            if (Buffer_Offset_Temp+5>Buffer_Size)
+            {
+                Element_WaitForMoreData();
+                return false;
+            }
+        }
+        if (Container_Bits==24)
+        {
+            while ((Buffer_TotalBytes+Buffer_Offset_Temp)%6) // Padding in part of the AES3 block
+            {
+                if (Buffer_Offset_Temp+1>Buffer_Size)
+                {
+                    Element_WaitForMoreData();
+                    return false;
+                }
+                if (Buffer[Buffer_Offset_Temp])
+                {
+                    Trusted_IsNot("Bad sync");
+                    return true;
+                }
+                Buffer_Offset_Temp++;
+            }
+            while(Buffer_Offset_Temp+6<=Buffer_Size && CC6(Buffer+Buffer_Offset_Temp)==0x000000000000LL)
+                Buffer_Offset_Temp+=6;
+            if (Buffer_Offset_Temp+6>Buffer_Size)
+            {
+                Element_WaitForMoreData();
+                return false;
+            }
+        }
+        else if (Container_Bits==32)
+        {
+            while ((Buffer_TotalBytes+Buffer_Offset_Temp)%8) // Padding in part of the AES3 block
+            {
+                if (Buffer_Offset_Temp+1>Buffer_Size)
+                {
+                    Element_WaitForMoreData();
+                    return false;
+                }
+                if (Buffer[Buffer_Offset_Temp])
+                {
+                    Trusted_IsNot("Bad sync");
+                    return true;
+                }
+                Buffer_Offset_Temp++;
+            }
+            while(Buffer_Offset_Temp+8<=Buffer_Size && CC8(Buffer+Buffer_Offset_Temp)==0x0000000000000000LL)
+                Buffer_Offset_Temp+=8;
+            if (Buffer_Offset_Temp+8>Buffer_Size)
+            {
+                Element_WaitForMoreData();
+                return false;
+            }
         }
     }
-    if (Container_Bits==20)
+    else
     {
-        while ((Buffer_TotalBytes+Buffer_Offset_Temp)%5) // Padding in part of the AES3 block
-        {
-            if (Buffer_Offset_Temp+1>Buffer_Size)
-            {
-                Element_WaitForMoreData();
-                return false;
-            }
-            if (Buffer[Buffer_Offset_Temp])
-            {
-                Trusted_IsNot("Bad sync");
-                return true;
-            }
+        while(Buffer_Offset_Temp+NullPadding_Size<Buffer_Size && !Buffer[Buffer_Offset_Temp+NullPadding_Size])
             Buffer_Offset_Temp++;
-        }
-        while(Buffer_Offset_Temp+5<=Buffer_Size && CC5(Buffer+Buffer_Offset_Temp)==0x0000000000LL)
-            Buffer_Offset_Temp+=5;
-        if (Buffer_Offset_Temp+5>Buffer_Size)
-        {
-            Element_WaitForMoreData();
-            return false;
-        }
-    }
-    if (Container_Bits==24)
-    {
-        while ((Buffer_TotalBytes+Buffer_Offset_Temp)%6) // Padding in part of the AES3 block
-        {
-            if (Buffer_Offset_Temp+1>Buffer_Size)
-            {
-                Element_WaitForMoreData();
-                return false;
-            }
-            if (Buffer[Buffer_Offset_Temp])
-            {
-                Trusted_IsNot("Bad sync");
-                return true;
-            }
-            Buffer_Offset_Temp++;
-        }
-        while(Buffer_Offset_Temp+6<=Buffer_Size && CC6(Buffer+Buffer_Offset_Temp)==0x000000000000LL)
-            Buffer_Offset_Temp+=6;
-        if (Buffer_Offset_Temp+6>Buffer_Size)
-        {
-            Element_WaitForMoreData();
-            return false;
-        }
-    }
-    else if (Container_Bits==32)
-    {
-        while ((Buffer_TotalBytes+Buffer_Offset_Temp)%8) // Padding in part of the AES3 block
-        {
-            if (Buffer_Offset_Temp+1>Buffer_Size)
-            {
-                Element_WaitForMoreData();
-                return false;
-            }
-            if (Buffer[Buffer_Offset_Temp])
-            {
-                Trusted_IsNot("Bad sync");
-                return true;
-            }
-            Buffer_Offset_Temp++;
-        }
-        while(Buffer_Offset_Temp+8<=Buffer_Size && CC8(Buffer+Buffer_Offset_Temp)==0x0000000000000000LL)
-            Buffer_Offset_Temp+=8;
-        if (Buffer_Offset_Temp+8>Buffer_Size)
+        if (Buffer_Offset_Temp+NullPadding_Size>=Buffer_Size)
         {
             Element_WaitForMoreData();
             return false;
@@ -705,8 +731,6 @@ bool File_SmpteSt0337::Synched_Test()
         {
             Element_Size=Buffer_Offset_Temp-Buffer_Offset;
             Skip_XX(Buffer_Offset_Temp-Buffer_Offset,           "Guard band");
-
-            GuardBand_Before+=Buffer_Offset_Temp-Buffer_Offset;
         }
     #endif // MEDIAINFO_TRACE
     Buffer_Offset=Buffer_Offset_Temp;
@@ -726,7 +750,7 @@ bool File_SmpteSt0337::Synched_Test()
                         case 24 :
                                     switch (Stream_Bits)
                                     {
-                                        case 16 : if (CC6(Buffer+Buffer_Offset)!=0xF872004E1F00LL) {Synched=false; return true;} break;
+                                        case 16 : if (CC6(Buffer+Buffer_Offset)!=0x00F872004E1FLL) {Synched=false; return true;} break;
                                         case 20 : if (CC6(Buffer+Buffer_Offset)!=0x6F872054E1F0LL) {Synched=false; return true;} break;
                                         case 24 : if (CC6(Buffer+Buffer_Offset)!=0x96F872A54E1FLL) {Synched=false; return true;} break;
                                         default : ;
@@ -773,6 +797,17 @@ bool File_SmpteSt0337::Synched_Test()
         default    : ; // Should never happen
     }
 
+    // Guard band
+    GuardBand_Before+=Buffer_Offset-Buffer_Offset_Base;
+    if (GuardBand_After)
+    {
+        if (GuardBand_Before>GuardBand_After)
+            GuardBand_Before-=GuardBand_After;
+        else
+            GuardBand_Before=0;
+        GuardBand_After=0;
+    }
+
     // We continue
     return true;
 }
@@ -782,8 +817,11 @@ void File_SmpteSt0337::Synched_Init()
 {
     if (Frame_Count_NotParsedIncluded==(int64u)-1)
         Frame_Count_NotParsedIncluded=0;
-    if (FrameInfo.DTS==(int64u)-1)
-        FrameInfo.DTS=0;
+    if (!IsSub)
+    {
+        FrameInfo.DTS=0; //No DTS in container
+        FrameInfo.PTS=0; //No PTS in container
+    }
 }
 
 //***************************************************************************
@@ -856,7 +894,6 @@ void File_SmpteSt0337::Header_Parse()
     if (Container_Bits!=Stream_Bits)
     {
         Size*=Container_Bits; Size/=Stream_Bits;
-        GuardBand_Before*=Container_Bits; GuardBand_Before/=Stream_Bits;
     }
 
     // Coherency test
@@ -873,7 +910,7 @@ void File_SmpteSt0337::Header_Parse()
         Offset/=Container_Bits/4;
         Offset*=Container_Bits/4;
         bool IsOK=true;
-        for (size_t Pos=0; Pos<Container_Bits/4; Pos++)
+        for (int8u Pos=0; Pos<Container_Bits/4; Pos++)
             if (Buffer[Buffer_Offset+Pos]!=Buffer[Offset+Pos])
             {
                 IsOK=false;
@@ -889,7 +926,7 @@ void File_SmpteSt0337::Header_Parse()
 
     // Filling
     Header_Fill_Size(Container_Bits*4/8+Size/8);
-    Header_Fill_Code(0, "AES3");
+    Header_Fill_Code(0, "SMPTE ST 337");
 }
 
 //---------------------------------------------------------------------------
@@ -903,9 +940,9 @@ void File_SmpteSt0337::Data_Parse()
 
     // Adapting
     const int8u* Save_Buffer=NULL;
-    size_t Save_Buffer_Offset;
-    size_t Save_Buffer_Size;
-    int64u Save_Element_Size;
+    size_t Save_Buffer_Offset=0;
+    size_t Save_Buffer_Size=0;
+    int64u Save_Element_Size=0;
 
     if (Endianness=='L'|| Container_Bits!=Stream_Bits)
     {
@@ -995,7 +1032,7 @@ void File_SmpteSt0337::Data_Parse()
         {
             // Source: 24LE / L1L0 L3L2 L5L3 R1R0 R3R2 R5R4
             // Dest  : 24BE / L5L3 L3L2 L1L0 R5R4 R3R2 R1R0
-            while (Element_Offset+8<=Element_Size)
+            while (Element_Offset+6<=Element_Size)
             {
                 size_t Buffer_Pos=Buffer_Offset+(size_t)Element_Offset;
 
@@ -1006,7 +1043,7 @@ void File_SmpteSt0337::Data_Parse()
                 *(Info_Temp++)= Buffer[Buffer_Pos+4]                                    ;
                 *(Info_Temp++)= Buffer[Buffer_Pos+3]                                    ;
 
-                Element_Offset+=8;
+                Element_Offset+=6;
             }
         }
 
@@ -1143,12 +1180,33 @@ void File_SmpteSt0337::Data_Parse()
                         break;
             case  7 :   // MPEG-2 AAC in ADTS
             case 19 :   // MPEG-2 AAC in ADTS low frequency
-                        Parser=new File_Aac();
-                        ((File_Aac*)Parser)->Mode=File_Aac::Mode_ADTS;
+                        #if defined(MEDIAINFO_AAC_YES)
+                            Parser=new File_Aac();
+                            ((File_Aac*)Parser)->Mode=File_Aac::Mode_ADTS;
+                        #else
+                        {
+                            //Filling
+                            File__Analyze* Parser=new File_Unknown();
+                            Open_Buffer_Init(Parser);
+                            Parser->Stream_Prepare(Stream_Audio);
+                            Parser->Fill(Stream_Audio, 0, Audio_Format, "AAC");
+                            Parser->Fill(Stream_Audio, 0, Audio_MuxingMode, "ADTS");
+                        }
+                        #endif //defined(MEDIAINFO_AAC_YES)
                         break;
             case 10 :   // MPEG-4 AAC in ADTS or LATM
             case 11 :   // MPEG-4 AAC in ADTS or LATM
-                        Parser=new File_Aac();
+                        #if defined(MEDIAINFO_AAC_YES)
+                            Parser=new File_Aac();
+                        #else
+                        {
+                            //Filling
+                            File__Analyze* Parser=new File_Unknown();
+                            Open_Buffer_Init(Parser);
+                            Parser->Stream_Prepare(Stream_Audio);
+                            Parser->Fill(Stream_Audio, 0, Audio_Format, "AAC");
+                        }
+                        #endif //defined(MEDIAINFO_AAC_YES)
                         break;
             case 28 :   // Dolby E
                         Parser=new File_DolbyE();
@@ -1207,6 +1265,8 @@ void File_SmpteSt0337::Data_Parse()
             }
             else
                 Demux(Buffer+Buffer_Offset, (size_t)Element_Size, ContentType_MainStream);
+
+            Element_Offset=Demux_Element_Offset;
         }
         else
             Demux(Buffer+Buffer_Offset+Container_Bits/2, (size_t)(Element_Size-Container_Bits/2), ContentType_MainStream);
@@ -1221,38 +1281,71 @@ void File_SmpteSt0337::Data_Parse()
         }
      #endif //MEDIAINFO_DEMUX
 
+    // Guard band
+    GuardBand_After=0;
+
     if (Parser && !Parser->Status[IsFinished])
     {
+        switch(data_type)
+        {
+            case 28 :
+                        ((File_DolbyE*)Parser)->GuardBand_Before=GuardBand_Before;
+                        ((File_DolbyE*)Parser)->GuardBand_Before*=Stream_Bits;
+                        ((File_DolbyE*)Parser)->GuardBand_Before/=Container_Bits;
+                        break;
+            default : ;
+        }
+
         Parser->FrameInfo=FrameInfo;
         Open_Buffer_Continue(Parser, Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)(Element_Size-Element_Offset));
         Element_Offset=Element_Size;
         #if MEDIAINFO_DEMUX
             FrameInfo.DUR=Parser->FrameInfo.DUR;
             if (FrameInfo.DUR!=(int64u)-1)
-                FrameInfo.DTS+=FrameInfo.DUR;
+            {
+                if (FrameInfo.DTS!=(int64u)-1)
+                    FrameInfo.DTS+=FrameInfo.DUR;
+                if (FrameInfo.PTS!=(int64u)-1)
+                    FrameInfo.PTS+=FrameInfo.DUR;
+            }
             else
+            {
                 FrameInfo.DTS=(int64u)-1;
-            FrameInfo.PTS=FrameInfo.DTS;
+                FrameInfo.PTS=(int64u)-1;
+            }
         #endif // MEDIAINFO_DEMUX
+
+        switch (data_type)
+        {
+            case 28 :
+                        GuardBand_After=((File_DolbyE*)Parser)->GuardBand_After;
+                        GuardBand_After*=Container_Bits;
+                        GuardBand_After/=Stream_Bits;
+                        break;
+            default : ;
+        }
     }
     else
     {
         Skip_XX(Element_Size-Element_Offset,                    "Data");
     }
 
-    FILLING_BEGIN()
+    FILLING_BEGIN();
         FrameSizes[IsSub?Buffer_Size:((GuardBand_Before+Element_Size)*Container_Bits/Stream_Bits)]++;
 
         Frame_Count++;
         if (Frame_Count_NotParsedIncluded!=(int64u)-1)
             Frame_Count_NotParsedIncluded++;
 
+        if (Parser==NULL || (Frame_Count>=2 && Parser->Status[IsFilled]))
+            Fill("SMPTE ST 337");
         if (Parser==NULL || (Frame_Count>=2 && Parser->Status[IsFinished]))
-            Finish("AES3");
+            Finish("SMPTE ST 337");
     FILLING_END();
 
     if (Save_Buffer)
     {
+        delete[] Buffer;
         Buffer=Save_Buffer;
         Buffer_Offset=Save_Buffer_Offset;
         Buffer_Size=Save_Buffer_Size;
