@@ -1,27 +1,15 @@
-// Enums - Automaticly generated enums for MediaInfo
-// Copyright (C) 2008-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Automaticly generated methods for MediaInfo
 // Don't modify, this will be deleted at the next automatic update
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 //---------------------------------------------------------------------------
 #ifndef MediaInfo_File__Analyze_AutomaticH
@@ -41,6 +29,8 @@ enum generic
     Generic_Format_Commercial_IfAny,
     Generic_Format_Version,
     Generic_Format_Profile,
+    Generic_Format_Level,
+    Generic_Format_Tier,
     Generic_Format_Compression,
     Generic_Format_Settings,
     Generic_InternetMediaType,
@@ -59,11 +49,15 @@ enum generic
     Generic_Duration_String1,
     Generic_Duration_String2,
     Generic_Duration_String3,
+    Generic_Duration_String4,
+    Generic_Duration_String5,
     Generic_Source_Duration,
     Generic_Source_Duration_String,
     Generic_Source_Duration_String1,
     Generic_Source_Duration_String2,
     Generic_Source_Duration_String3,
+    Generic_Source_Duration_String4,
+    Generic_Source_Duration_String5,
     Generic_BitRate_Mode,
     Generic_BitRate_Mode_String,
     Generic_BitRate,
@@ -76,6 +70,10 @@ enum generic
     Generic_BitRate_Maximum_String,
     Generic_BitRate_Encoded,
     Generic_BitRate_Encoded_String,
+    Generic_FrameRate,
+    Generic_FrameRate_String,
+    Generic_FrameRate_Num,
+    Generic_FrameRate_Den,
     Generic_FrameCount,
     Generic_Source_FrameCount,
     Generic_ColorSpace,
@@ -93,6 +91,7 @@ enum generic
     Generic_Delay_String2,
     Generic_Delay_String3,
     Generic_Delay_String4,
+    Generic_Delay_String5,
     Generic_Delay_Settings,
     Generic_Delay_DropFrame,
     Generic_Delay_Source,
@@ -103,6 +102,7 @@ enum generic
     Generic_Delay_Original_String2,
     Generic_Delay_Original_String3,
     Generic_Delay_Original_String4,
+    Generic_Delay_Original_String5,
     Generic_Delay_Original_Settings,
     Generic_Delay_Original_DropFrame,
     Generic_Delay_Original_Source,
@@ -112,6 +112,7 @@ enum generic
     Generic_Video_Delay_String2,
     Generic_Video_Delay_String3,
     Generic_Video_Delay_String4,
+    Generic_Video_Delay_String5,
     Generic_StreamSize,
     Generic_StreamSize_String,
     Generic_StreamSize_String1,
@@ -164,6 +165,8 @@ enum general
     General_Inform,
     General_ID,
     General_ID_String,
+    General_OriginalSourceMedium_ID,
+    General_OriginalSourceMedium_ID_String,
     General_UniqueID,
     General_UniqueID_String,
     General_MenuID,
@@ -216,6 +219,7 @@ enum general
     General_Format_Commercial_IfAny,
     General_Format_Version,
     General_Format_Profile,
+    General_Format_Level,
     General_Format_Compression,
     General_Format_Settings,
     General_InternetMediaType,
@@ -225,6 +229,8 @@ enum general
     General_CodecID_Hint,
     General_CodecID_Url,
     General_CodecID_Description,
+    General_CodecID_Version,
+    General_CodecID_Compatible,
     General_Interleaved,
     General_Codec,
     General_Codec_String,
@@ -244,6 +250,8 @@ enum general
     General_Duration_String1,
     General_Duration_String2,
     General_Duration_String3,
+    General_Duration_String4,
+    General_Duration_String5,
     General_Duration_Start,
     General_Duration_End,
     General_OverallBitRate_Mode,
@@ -256,11 +264,22 @@ enum general
     General_OverallBitRate_Nominal_String,
     General_OverallBitRate_Maximum,
     General_OverallBitRate_Maximum_String,
+    General_FrameRate,
+    General_FrameRate_String,
+    General_FrameRate_Num,
+    General_FrameRate_Den,
+    General_FrameCount,
     General_Delay,
     General_Delay_String,
     General_Delay_String1,
     General_Delay_String2,
     General_Delay_String3,
+    General_Delay_String4,
+    General_Delay_String5,
+    General_Delay_Settings,
+    General_Delay_DropFrame,
+    General_Delay_Source,
+    General_Delay_Source_String,
     General_StreamSize,
     General_StreamSize_String,
     General_StreamSize_String1,
@@ -269,6 +288,13 @@ enum general
     General_StreamSize_String4,
     General_StreamSize_String5,
     General_StreamSize_Proportion,
+    General_StreamSize_Demuxed,
+    General_StreamSize_Demuxed_String,
+    General_StreamSize_Demuxed_String1,
+    General_StreamSize_Demuxed_String2,
+    General_StreamSize_Demuxed_String3,
+    General_StreamSize_Demuxed_String4,
+    General_StreamSize_Demuxed_String5,
     General_HeaderSize,
     General_DataSize,
     General_FooterSize,
@@ -277,6 +303,12 @@ enum general
     General_Album_ReplayGain_Gain_String,
     General_Album_ReplayGain_Peak,
     General_Encryption,
+    General_Encryption_Format,
+    General_Encryption_Length,
+    General_Encryption_Method,
+    General_Encryption_Mode,
+    General_Encryption_Padding,
+    General_Encryption_InitializationVector,
     General_Title,
     General_Title_More,
     General_Title_Url,
@@ -307,6 +339,7 @@ enum general
     General_Track_Sort,
     General_Track_Position,
     General_Track_Position_Total,
+    General_PackageName,
     General_Grouping,
     General_Chapter,
     General_SubTrack,
@@ -323,11 +356,13 @@ enum general
     General_Accompaniment,
     General_Composer,
     General_Composer_Nationality,
+    General_Composer_Sort,
     General_Arranger,
     General_Lyricist,
     General_Original_Lyricist,
     General_Conductor,
     General_Director,
+    General_CoDirector,
     General_AssistantDirector,
     General_DirectorOfPhotography,
     General_SoundEngineer,
@@ -356,6 +391,7 @@ enum general
     General_Publisher_URL,
     General_Label,
     General_Genre,
+    General_PodcastCategory,
     General_Mood,
     General_ContentType,
     General_Subject,
@@ -382,13 +418,19 @@ enum general
     General_Written_Location,
     General_Archival_Location,
     General_Encoded_Application,
+    General_Encoded_Application_String,
+    General_Encoded_Application_CompanyName,
+    General_Encoded_Application_Name,
+    General_Encoded_Application_Version,
     General_Encoded_Application_Url,
     General_Encoded_Library,
     General_Encoded_Library_String,
+    General_Encoded_Library_CompanyName,
     General_Encoded_Library_Name,
     General_Encoded_Library_Version,
     General_Encoded_Library_Date,
     General_Encoded_Library_Settings,
+    General_Encoded_OperatingSystem,
     General_Cropped,
     General_Dimensions,
     General_DotsPerInch,
@@ -453,6 +495,8 @@ enum video
     Video_Inform,
     Video_ID,
     Video_ID_String,
+    Video_OriginalSourceMedium_ID,
+    Video_OriginalSourceMedium_ID_String,
     Video_UniqueID,
     Video_UniqueID_String,
     Video_MenuID,
@@ -464,6 +508,8 @@ enum video
     Video_Format_Commercial_IfAny,
     Video_Format_Version,
     Video_Format_Profile,
+    Video_Format_Level,
+    Video_Format_Tier,
     Video_Format_Compression,
     Video_MultiView_BaseProfile,
     Video_MultiView_Count,
@@ -485,7 +531,7 @@ enum video
     Video_Format_Settings_Pulldown,
     Video_Format_Settings_FrameMode,
     Video_Format_Settings_GOP,
-    Video_Format_Settings_FrameStructures,
+    Video_Format_Settings_PictureStructure,
     Video_Format_Settings_Wrapping,
     Video_InternetMediaType,
     Video_MuxingMode,
@@ -519,31 +565,42 @@ enum video
     Video_Duration_String2,
     Video_Duration_String3,
     Video_Duration_String4,
+    Video_Duration_String5,
     Video_Duration_FirstFrame,
     Video_Duration_FirstFrame_String,
     Video_Duration_FirstFrame_String1,
     Video_Duration_FirstFrame_String2,
     Video_Duration_FirstFrame_String3,
+    Video_Duration_FirstFrame_String4,
+    Video_Duration_FirstFrame_String5,
     Video_Duration_LastFrame,
     Video_Duration_LastFrame_String,
     Video_Duration_LastFrame_String1,
     Video_Duration_LastFrame_String2,
     Video_Duration_LastFrame_String3,
+    Video_Duration_LastFrame_String4,
+    Video_Duration_LastFrame_String5,
     Video_Source_Duration,
     Video_Source_Duration_String,
     Video_Source_Duration_String1,
     Video_Source_Duration_String2,
     Video_Source_Duration_String3,
+    Video_Source_Duration_String4,
+    Video_Source_Duration_String5,
     Video_Source_Duration_FirstFrame,
     Video_Source_Duration_FirstFrame_String,
     Video_Source_Duration_FirstFrame_String1,
     Video_Source_Duration_FirstFrame_String2,
     Video_Source_Duration_FirstFrame_String3,
+    Video_Source_Duration_FirstFrame_String4,
+    Video_Source_Duration_FirstFrame_String5,
     Video_Source_Duration_LastFrame,
     Video_Source_Duration_LastFrame_String,
     Video_Source_Duration_LastFrame_String1,
     Video_Source_Duration_LastFrame_String2,
     Video_Source_Duration_LastFrame_String3,
+    Video_Source_Duration_LastFrame_String4,
+    Video_Source_Duration_LastFrame_String5,
     Video_BitRate_Mode,
     Video_BitRate_Mode_String,
     Video_BitRate,
@@ -562,20 +619,32 @@ enum video
     Video_Width_Offset_String,
     Video_Width_Original,
     Video_Width_Original_String,
+    Video_Width_CleanAperture,
+    Video_Width_CleanAperture_String,
     Video_Height,
     Video_Height_String,
     Video_Height_Offset,
     Video_Height_Offset_String,
     Video_Height_Original,
     Video_Height_Original_String,
+    Video_Height_CleanAperture,
+    Video_Height_CleanAperture_String,
+    Video_Stored_Width,
+    Video_Stored_Height,
+    Video_Sampled_Width,
+    Video_Sampled_Height,
     Video_PixelAspectRatio,
     Video_PixelAspectRatio_String,
     Video_PixelAspectRatio_Original,
     Video_PixelAspectRatio_Original_String,
+    Video_PixelAspectRatio_CleanAperture,
+    Video_PixelAspectRatio_CleanAperture_String,
     Video_DisplayAspectRatio,
     Video_DisplayAspectRatio_String,
     Video_DisplayAspectRatio_Original,
     Video_DisplayAspectRatio_Original_String,
+    Video_DisplayAspectRatio_CleanAperture,
+    Video_DisplayAspectRatio_CleanAperture_String,
     Video_ActiveFormatDescription,
     Video_ActiveFormatDescription_String,
     Video_ActiveFormatDescription_MuxingMode,
@@ -587,14 +656,18 @@ enum video
     Video_FrameRate_Mode_Original_String,
     Video_FrameRate,
     Video_FrameRate_String,
-    Video_FrameRate_Original,
-    Video_FrameRate_Original_String,
+    Video_FrameRate_Num,
+    Video_FrameRate_Den,
     Video_FrameRate_Minimum,
     Video_FrameRate_Minimum_String,
     Video_FrameRate_Nominal,
     Video_FrameRate_Nominal_String,
     Video_FrameRate_Maximum,
     Video_FrameRate_Maximum_String,
+    Video_FrameRate_Original,
+    Video_FrameRate_Original_String,
+    Video_FrameRate_Original_Num,
+    Video_FrameRate_Original_Den,
     Video_FrameCount,
     Video_Source_FrameCount,
     Video_Standard,
@@ -603,14 +676,22 @@ enum video
     Video_Colorimetry,
     Video_ColorSpace,
     Video_ChromaSubsampling,
+    Video_ChromaSubsampling_String,
+    Video_ChromaSubsampling_Position,
     Video_BitDepth,
     Video_BitDepth_String,
     Video_ScanType,
     Video_ScanType_String,
     Video_ScanType_Original,
     Video_ScanType_Original_String,
+    Video_ScanType_StoreMethod,
+    Video_ScanType_StoreMethod_FieldsPerBlock,
+    Video_ScanType_StoreMethod_String,
     Video_ScanOrder,
     Video_ScanOrder_String,
+    Video_ScanOrder_Stored,
+    Video_ScanOrder_Stored_String,
+    Video_ScanOrder_StoredDisplayedInverted,
     Video_ScanOrder_Original,
     Video_ScanOrder_Original_String,
     Video_Interlacement,
@@ -625,6 +706,7 @@ enum video
     Video_Delay_String2,
     Video_Delay_String3,
     Video_Delay_String4,
+    Video_Delay_String5,
     Video_Delay_Settings,
     Video_Delay_DropFrame,
     Video_Delay_Source,
@@ -635,6 +717,7 @@ enum video
     Video_Delay_Original_String2,
     Video_Delay_Original_String3,
     Video_Delay_Original_String4,
+    Video_Delay_Original_String5,
     Video_Delay_Original_Settings,
     Video_Delay_Original_DropFrame,
     Video_Delay_Original_Source,
@@ -643,9 +726,15 @@ enum video
     Video_TimeStamp_FirstFrame_String1,
     Video_TimeStamp_FirstFrame_String2,
     Video_TimeStamp_FirstFrame_String3,
+    Video_TimeStamp_FirstFrame_String4,
+    Video_TimeStamp_FirstFrame_String5,
     Video_TimeCode_FirstFrame,
     Video_TimeCode_Settings,
     Video_TimeCode_Source,
+    Video_Gop_OpenClosed,
+    Video_Gop_OpenClosed_String,
+    Video_Gop_OpenClosed_FirstFrame,
+    Video_Gop_OpenClosed_FirstFrame_String,
     Video_StreamSize,
     Video_StreamSize_String,
     Video_StreamSize_String1,
@@ -654,6 +743,13 @@ enum video
     Video_StreamSize_String4,
     Video_StreamSize_String5,
     Video_StreamSize_Proportion,
+    Video_StreamSize_Demuxed,
+    Video_StreamSize_Demuxed_String,
+    Video_StreamSize_Demuxed_String1,
+    Video_StreamSize_Demuxed_String2,
+    Video_StreamSize_Demuxed_String3,
+    Video_StreamSize_Demuxed_String4,
+    Video_StreamSize_Demuxed_String5,
     Video_Source_StreamSize,
     Video_Source_StreamSize_String,
     Video_Source_StreamSize_String1,
@@ -682,13 +778,19 @@ enum video
     Video_Alignment_String,
     Video_Title,
     Video_Encoded_Application,
+    Video_Encoded_Application_String,
+    Video_Encoded_Application_CompanyName,
+    Video_Encoded_Application_Name,
+    Video_Encoded_Application_Version,
     Video_Encoded_Application_Url,
     Video_Encoded_Library,
     Video_Encoded_Library_String,
+    Video_Encoded_Library_CompanyName,
     Video_Encoded_Library_Name,
     Video_Encoded_Library_Version,
     Video_Encoded_Library_Date,
     Video_Encoded_Library_Settings,
+    Video_Encoded_OperatingSystem,
     Video_Language,
     Video_Language_String,
     Video_Language_String1,
@@ -696,14 +798,27 @@ enum video
     Video_Language_String3,
     Video_Language_String4,
     Video_Language_More,
+    Video_Disabled,
+    Video_Disabled_String,
     Video_Default,
     Video_Default_String,
     Video_Forced,
     Video_Forced_String,
+    Video_AlternateGroup,
+    Video_AlternateGroup_String,
     Video_Encoded_Date,
     Video_Tagged_Date,
     Video_Encryption,
     Video_BufferSize,
+    Video_colour_range,
+    Video_colour_description_present,
+    Video_colour_primaries,
+    Video_transfer_characteristics,
+    Video_matrix_coefficients,
+    Video_colour_description_present_Original,
+    Video_colour_primaries_Original,
+    Video_transfer_characteristics_Original,
+    Video_matrix_coefficients_Original,
 };
 
 //---------------------------------------------------------------------------
@@ -721,6 +836,8 @@ enum audio
     Audio_Inform,
     Audio_ID,
     Audio_ID_String,
+    Audio_OriginalSourceMedium_ID,
+    Audio_OriginalSourceMedium_ID_String,
     Audio_UniqueID,
     Audio_UniqueID_String,
     Audio_MenuID,
@@ -732,6 +849,7 @@ enum audio
     Audio_Format_Commercial_IfAny,
     Audio_Format_Version,
     Audio_Format_Profile,
+    Audio_Format_Level,
     Audio_Format_Compression,
     Audio_Format_Settings,
     Audio_Format_Settings_SBR,
@@ -748,6 +866,7 @@ enum audio
     Audio_Format_Settings_Law,
     Audio_Format_Settings_ITU,
     Audio_Format_Settings_Wrapping,
+    Audio_Matrix_Format,
     Audio_InternetMediaType,
     Audio_MuxingMode,
     Audio_MuxingMode_MoreInfo,
@@ -778,31 +897,43 @@ enum audio
     Audio_Duration_String1,
     Audio_Duration_String2,
     Audio_Duration_String3,
+    Audio_Duration_String4,
+    Audio_Duration_String5,
     Audio_Duration_FirstFrame,
     Audio_Duration_FirstFrame_String,
     Audio_Duration_FirstFrame_String1,
     Audio_Duration_FirstFrame_String2,
     Audio_Duration_FirstFrame_String3,
+    Audio_Duration_FirstFrame_String4,
+    Audio_Duration_FirstFrame_String5,
     Audio_Duration_LastFrame,
     Audio_Duration_LastFrame_String,
     Audio_Duration_LastFrame_String1,
     Audio_Duration_LastFrame_String2,
     Audio_Duration_LastFrame_String3,
+    Audio_Duration_LastFrame_String4,
+    Audio_Duration_LastFrame_String5,
     Audio_Source_Duration,
     Audio_Source_Duration_String,
     Audio_Source_Duration_String1,
     Audio_Source_Duration_String2,
     Audio_Source_Duration_String3,
+    Audio_Source_Duration_String4,
+    Audio_Source_Duration_String5,
     Audio_Source_Duration_FirstFrame,
     Audio_Source_Duration_FirstFrame_String,
     Audio_Source_Duration_FirstFrame_String1,
     Audio_Source_Duration_FirstFrame_String2,
     Audio_Source_Duration_FirstFrame_String3,
+    Audio_Source_Duration_FirstFrame_String4,
+    Audio_Source_Duration_FirstFrame_String5,
     Audio_Source_Duration_LastFrame,
     Audio_Source_Duration_LastFrame_String,
     Audio_Source_Duration_LastFrame_String1,
     Audio_Source_Duration_LastFrame_String2,
     Audio_Source_Duration_LastFrame_String3,
+    Audio_Source_Duration_LastFrame_String4,
+    Audio_Source_Duration_LastFrame_String5,
     Audio_BitRate_Mode,
     Audio_BitRate_Mode_String,
     Audio_BitRate,
@@ -817,21 +948,35 @@ enum audio
     Audio_BitRate_Encoded_String,
     Audio_Channel_s_,
     Audio_Channel_s__String,
+    Audio_Channel_s__Original,
+    Audio_Channel_s__Original_String,
+    Audio_Matrix_Channel_s_,
+    Audio_Matrix_Channel_s__String,
     Audio_ChannelPositions,
     Audio_ChannelPositions_String2,
+    Audio_Matrix_ChannelPositions,
+    Audio_Matrix_ChannelPositions_String2,
     Audio_ChannelLayout,
+    Audio_ChannelLayoutID,
+    Audio_SamplesPerFrame,
     Audio_SamplingRate,
     Audio_SamplingRate_String,
     Audio_SamplingCount,
     Audio_Source_SamplingCount,
     Audio_FrameRate,
     Audio_FrameRate_String,
+    Audio_FrameRate_Num,
+    Audio_FrameRate_Den,
     Audio_FrameCount,
     Audio_Source_FrameCount,
     Audio_Resolution,
     Audio_Resolution_String,
     Audio_BitDepth,
     Audio_BitDepth_String,
+    Audio_BitDepth_Detected,
+    Audio_BitDepth_Detected_String,
+    Audio_BitDepth_Stored,
+    Audio_BitDepth_Stored_String,
     Audio_Compression_Mode,
     Audio_Compression_Mode_String,
     Audio_Compression_Ratio,
@@ -841,6 +986,7 @@ enum audio
     Audio_Delay_String2,
     Audio_Delay_String3,
     Audio_Delay_String4,
+    Audio_Delay_String5,
     Audio_Delay_Settings,
     Audio_Delay_DropFrame,
     Audio_Delay_Source,
@@ -851,6 +997,7 @@ enum audio
     Audio_Delay_Original_String2,
     Audio_Delay_Original_String3,
     Audio_Delay_Original_String4,
+    Audio_Delay_Original_String5,
     Audio_Delay_Original_Settings,
     Audio_Delay_Original_DropFrame,
     Audio_Delay_Original_Source,
@@ -860,12 +1007,14 @@ enum audio
     Audio_Video_Delay_String2,
     Audio_Video_Delay_String3,
     Audio_Video_Delay_String4,
+    Audio_Video_Delay_String5,
     Audio_Video0_Delay,
     Audio_Video0_Delay_String,
     Audio_Video0_Delay_String1,
     Audio_Video0_Delay_String2,
     Audio_Video0_Delay_String3,
     Audio_Video0_Delay_String4,
+    Audio_Video0_Delay_String5,
     Audio_ReplayGain_Gain,
     Audio_ReplayGain_Gain_String,
     Audio_ReplayGain_Peak,
@@ -877,6 +1026,13 @@ enum audio
     Audio_StreamSize_String4,
     Audio_StreamSize_String5,
     Audio_StreamSize_Proportion,
+    Audio_StreamSize_Demuxed,
+    Audio_StreamSize_Demuxed_String,
+    Audio_StreamSize_Demuxed_String1,
+    Audio_StreamSize_Demuxed_String2,
+    Audio_StreamSize_Demuxed_String3,
+    Audio_StreamSize_Demuxed_String4,
+    Audio_StreamSize_Demuxed_String5,
     Audio_Source_StreamSize,
     Audio_Source_StreamSize_String,
     Audio_Source_StreamSize_String1,
@@ -909,12 +1065,20 @@ enum audio
     Audio_Interleave_Preload,
     Audio_Interleave_Preload_String,
     Audio_Title,
+    Audio_Encoded_Application,
+    Audio_Encoded_Application_String,
+    Audio_Encoded_Application_CompanyName,
+    Audio_Encoded_Application_Name,
+    Audio_Encoded_Application_Version,
+    Audio_Encoded_Application_Url,
     Audio_Encoded_Library,
     Audio_Encoded_Library_String,
+    Audio_Encoded_Library_CompanyName,
     Audio_Encoded_Library_Name,
     Audio_Encoded_Library_Version,
     Audio_Encoded_Library_Date,
     Audio_Encoded_Library_Settings,
+    Audio_Encoded_OperatingSystem,
     Audio_Language,
     Audio_Language_String,
     Audio_Language_String1,
@@ -922,10 +1086,14 @@ enum audio
     Audio_Language_String3,
     Audio_Language_String4,
     Audio_Language_More,
+    Audio_Disabled,
+    Audio_Disabled_String,
     Audio_Default,
     Audio_Default_String,
     Audio_Forced,
     Audio_Forced_String,
+    Audio_AlternateGroup,
+    Audio_AlternateGroup_String,
     Audio_Encoded_Date,
     Audio_Tagged_Date,
     Audio_Encryption,
@@ -946,6 +1114,8 @@ enum text
     Text_Inform,
     Text_ID,
     Text_ID_String,
+    Text_OriginalSourceMedium_ID,
+    Text_OriginalSourceMedium_ID_String,
     Text_UniqueID,
     Text_UniqueID_String,
     Text_MenuID,
@@ -980,31 +1150,42 @@ enum text
     Text_Duration_String2,
     Text_Duration_String3,
     Text_Duration_String4,
+    Text_Duration_String5,
     Text_Duration_FirstFrame,
     Text_Duration_FirstFrame_String,
     Text_Duration_FirstFrame_String1,
     Text_Duration_FirstFrame_String2,
     Text_Duration_FirstFrame_String3,
+    Text_Duration_FirstFrame_String4,
+    Text_Duration_FirstFrame_String5,
     Text_Duration_LastFrame,
     Text_Duration_LastFrame_String,
     Text_Duration_LastFrame_String1,
     Text_Duration_LastFrame_String2,
     Text_Duration_LastFrame_String3,
+    Text_Duration_LastFrame_String4,
+    Text_Duration_LastFrame_String5,
     Text_Source_Duration,
     Text_Source_Duration_String,
     Text_Source_Duration_String1,
     Text_Source_Duration_String2,
     Text_Source_Duration_String3,
+    Text_Source_Duration_String4,
+    Text_Source_Duration_String5,
     Text_Source_Duration_FirstFrame,
     Text_Source_Duration_FirstFrame_String,
     Text_Source_Duration_FirstFrame_String1,
     Text_Source_Duration_FirstFrame_String2,
     Text_Source_Duration_FirstFrame_String3,
+    Text_Source_Duration_FirstFrame_String4,
+    Text_Source_Duration_FirstFrame_String5,
     Text_Source_Duration_LastFrame,
     Text_Source_Duration_LastFrame_String,
     Text_Source_Duration_LastFrame_String1,
     Text_Source_Duration_LastFrame_String2,
     Text_Source_Duration_LastFrame_String3,
+    Text_Source_Duration_LastFrame_String4,
+    Text_Source_Duration_LastFrame_String5,
     Text_BitRate_Mode,
     Text_BitRate_Mode_String,
     Text_BitRate,
@@ -1025,6 +1206,8 @@ enum text
     Text_FrameRate_Mode_String,
     Text_FrameRate,
     Text_FrameRate_String,
+    Text_FrameRate_Num,
+    Text_FrameRate_Den,
     Text_FrameRate_Minimum,
     Text_FrameRate_Minimum_String,
     Text_FrameRate_Nominal,
@@ -1034,6 +1217,7 @@ enum text
     Text_FrameRate_Original,
     Text_FrameRate_Original_String,
     Text_FrameCount,
+    Text_ElementCount,
     Text_Source_FrameCount,
     Text_ColorSpace,
     Text_ChromaSubsampling,
@@ -1050,6 +1234,7 @@ enum text
     Text_Delay_String2,
     Text_Delay_String3,
     Text_Delay_String4,
+    Text_Delay_String5,
     Text_Delay_Settings,
     Text_Delay_DropFrame,
     Text_Delay_Source,
@@ -1060,6 +1245,7 @@ enum text
     Text_Delay_Original_String2,
     Text_Delay_Original_String3,
     Text_Delay_Original_String4,
+    Text_Delay_Original_String5,
     Text_Delay_Original_Settings,
     Text_Delay_Original_DropFrame,
     Text_Delay_Original_Source,
@@ -1069,12 +1255,14 @@ enum text
     Text_Video_Delay_String2,
     Text_Video_Delay_String3,
     Text_Video_Delay_String4,
+    Text_Video_Delay_String5,
     Text_Video0_Delay,
     Text_Video0_Delay_String,
     Text_Video0_Delay_String1,
     Text_Video0_Delay_String2,
     Text_Video0_Delay_String3,
     Text_Video0_Delay_String4,
+    Text_Video0_Delay_String5,
     Text_StreamSize,
     Text_StreamSize_String,
     Text_StreamSize_String1,
@@ -1083,6 +1271,13 @@ enum text
     Text_StreamSize_String4,
     Text_StreamSize_String5,
     Text_StreamSize_Proportion,
+    Text_StreamSize_Demuxed,
+    Text_StreamSize_Demuxed_String,
+    Text_StreamSize_Demuxed_String1,
+    Text_StreamSize_Demuxed_String2,
+    Text_StreamSize_Demuxed_String3,
+    Text_StreamSize_Demuxed_String4,
+    Text_StreamSize_Demuxed_String5,
     Text_Source_StreamSize,
     Text_Source_StreamSize_String,
     Text_Source_StreamSize_String1,
@@ -1108,12 +1303,20 @@ enum text
     Text_Source_StreamSize_Encoded_String5,
     Text_Source_StreamSize_Encoded_Proportion,
     Text_Title,
+    Text_Encoded_Application,
+    Text_Encoded_Application_String,
+    Text_Encoded_Application_CompanyName,
+    Text_Encoded_Application_Name,
+    Text_Encoded_Application_Version,
+    Text_Encoded_Application_Url,
     Text_Encoded_Library,
     Text_Encoded_Library_String,
+    Text_Encoded_Library_CompanyName,
     Text_Encoded_Library_Name,
     Text_Encoded_Library_Version,
     Text_Encoded_Library_Date,
     Text_Encoded_Library_Settings,
+    Text_Encoded_OperatingSystem,
     Text_Language,
     Text_Language_String,
     Text_Language_String1,
@@ -1121,10 +1324,14 @@ enum text
     Text_Language_String3,
     Text_Language_String4,
     Text_Language_More,
+    Text_Disabled,
+    Text_Disabled_String,
     Text_Default,
     Text_Default_String,
     Text_Forced,
     Text_Forced_String,
+    Text_AlternateGroup,
+    Text_AlternateGroup_String,
     Text_Summary,
     Text_Encoded_Date,
     Text_Tagged_Date,
@@ -1146,6 +1353,8 @@ enum other
     Other_Inform,
     Other_ID,
     Other_ID_String,
+    Other_OriginalSourceMedium_ID,
+    Other_OriginalSourceMedium_ID_String,
     Other_UniqueID,
     Other_UniqueID_String,
     Other_MenuID,
@@ -1172,18 +1381,61 @@ enum other
     Other_Duration_String1,
     Other_Duration_String2,
     Other_Duration_String3,
+    Other_Duration_String4,
+    Other_Duration_String5,
     Other_Duration_Start,
     Other_Duration_End,
     Other_FrameRate,
     Other_FrameRate_String,
+    Other_FrameRate_Num,
+    Other_FrameRate_Den,
     Other_FrameCount,
+    Other_Delay,
+    Other_Delay_String,
+    Other_Delay_String1,
+    Other_Delay_String2,
+    Other_Delay_String3,
+    Other_Delay_String4,
+    Other_Delay_String5,
+    Other_Delay_Settings,
+    Other_Delay_DropFrame,
+    Other_Delay_Source,
+    Other_Delay_Source_String,
+    Other_Delay_Original,
+    Other_Delay_Original_String,
+    Other_Delay_Original_String1,
+    Other_Delay_Original_String2,
+    Other_Delay_Original_String3,
+    Other_Delay_Original_String4,
+    Other_Delay_Original_String5,
+    Other_Delay_Original_Settings,
+    Other_Delay_Original_DropFrame,
+    Other_Delay_Original_Source,
+    Other_Video_Delay,
+    Other_Video_Delay_String,
+    Other_Video_Delay_String1,
+    Other_Video_Delay_String2,
+    Other_Video_Delay_String3,
+    Other_Video_Delay_String4,
+    Other_Video_Delay_String5,
+    Other_Video0_Delay,
+    Other_Video0_Delay_String,
+    Other_Video0_Delay_String1,
+    Other_Video0_Delay_String2,
+    Other_Video0_Delay_String3,
+    Other_Video0_Delay_String4,
+    Other_Video0_Delay_String5,
     Other_TimeStamp_FirstFrame,
     Other_TimeStamp_FirstFrame_String,
     Other_TimeStamp_FirstFrame_String1,
     Other_TimeStamp_FirstFrame_String2,
     Other_TimeStamp_FirstFrame_String3,
+    Other_TimeStamp_FirstFrame_String4,
+    Other_TimeStamp_FirstFrame_String5,
     Other_TimeCode_FirstFrame,
     Other_TimeCode_Settings,
+    Other_TimeCode_Striped,
+    Other_TimeCode_Striped_String,
     Other_Title,
     Other_Language,
     Other_Language_String,
@@ -1192,6 +1444,14 @@ enum other
     Other_Language_String3,
     Other_Language_String4,
     Other_Language_More,
+    Other_Disabled,
+    Other_Disabled_String,
+    Other_Default,
+    Other_Default_String,
+    Other_Forced,
+    Other_Forced_String,
+    Other_AlternateGroup,
+    Other_AlternateGroup_String,
 };
 
 //---------------------------------------------------------------------------
@@ -1209,6 +1469,8 @@ enum image
     Image_Inform,
     Image_ID,
     Image_ID_String,
+    Image_OriginalSourceMedium_ID,
+    Image_OriginalSourceMedium_ID_String,
     Image_UniqueID,
     Image_UniqueID_String,
     Image_MenuID,
@@ -1273,6 +1535,13 @@ enum image
     Image_StreamSize_String4,
     Image_StreamSize_String5,
     Image_StreamSize_Proportion,
+    Image_StreamSize_Demuxed,
+    Image_StreamSize_Demuxed_String,
+    Image_StreamSize_Demuxed_String1,
+    Image_StreamSize_Demuxed_String2,
+    Image_StreamSize_Demuxed_String3,
+    Image_StreamSize_Demuxed_String4,
+    Image_StreamSize_Demuxed_String5,
     Image_Encoded_Library,
     Image_Encoded_Library_String,
     Image_Encoded_Library_Name,
@@ -1286,14 +1555,26 @@ enum image
     Image_Language_String3,
     Image_Language_String4,
     Image_Language_More,
+    Image_Disabled,
+    Image_Disabled_String,
     Image_Default,
     Image_Default_String,
     Image_Forced,
     Image_Forced_String,
+    Image_AlternateGroup,
+    Image_AlternateGroup_String,
     Image_Summary,
     Image_Encoded_Date,
     Image_Tagged_Date,
     Image_Encryption,
+    Image_colour_description_present,
+    Image_colour_primaries,
+    Image_transfer_characteristics,
+    Image_matrix_coefficients,
+    Image_colour_description_present_Original,
+    Image_colour_primaries_Original,
+    Image_transfer_characteristics_Original,
+    Image_matrix_coefficients_Original,
 };
 
 //---------------------------------------------------------------------------
@@ -1311,6 +1592,8 @@ enum menu
     Menu_Inform,
     Menu_ID,
     Menu_ID_String,
+    Menu_OriginalSourceMedium_ID,
+    Menu_OriginalSourceMedium_ID_String,
     Menu_UniqueID,
     Menu_UniqueID_String,
     Menu_MenuID,
@@ -1339,6 +1622,8 @@ enum menu
     Menu_Duration_String1,
     Menu_Duration_String2,
     Menu_Duration_String3,
+    Menu_Duration_String4,
+    Menu_Duration_String5,
     Menu_Duration_Start,
     Menu_Duration_End,
     Menu_Delay,
@@ -1347,6 +1632,7 @@ enum menu
     Menu_Delay_String2,
     Menu_Delay_String3,
     Menu_Delay_String4,
+    Menu_Delay_String5,
     Menu_Delay_Settings,
     Menu_Delay_DropFrame,
     Menu_Delay_Source,
@@ -1372,6 +1658,16 @@ enum menu
     Menu_Original_NetworkName,
     Menu_Countries,
     Menu_TimeZones,
+    Menu_LawRating,
+    Menu_LawRating_Reason,
+    Menu_Disabled,
+    Menu_Disabled_String,
+    Menu_Default,
+    Menu_Default_String,
+    Menu_Forced,
+    Menu_Forced_String,
+    Menu_AlternateGroup,
+    Menu_AlternateGroup_String,
     Menu_Chapters_Pos_Begin,
     Menu_Chapters_Pos_End,
 };
