@@ -1,21 +1,8 @@
-// File__Analyze - Base for analyze files
-// Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -99,26 +86,30 @@ extern MediaInfo_Config Config;
 //---------------------------------------------------------------------------
 void File__Analyze::BS_Begin()
 {
-    if (Element_Offset>Element_Size)
-        Element_Offset=Element_Size;
     size_t BS_Size;
-    if (Buffer_Offset+Element_Size<=Buffer_Size)
+    if (Element_Offset>=Element_Size)
+        BS_Size=0;
+    else if (Buffer_Offset+Element_Size<=Buffer_Size)
         BS_Size=(size_t)(Element_Size-Element_Offset);
+    else if (Buffer_Offset+Element_Offset<=Buffer_Size)
+        BS_Size=Buffer_Size-(size_t)(Buffer_Offset+Element_Offset);
     else
-        BS_Size=Buffer_Size-(Buffer_Offset+(size_t)Element_Offset);
+        BS_Size=0;
+
     BS->Attach(Buffer+Buffer_Offset+(size_t)Element_Offset, BS_Size);
 }
 
 //---------------------------------------------------------------------------
 void File__Analyze::BS_Begin_LE()
 {
-    if (Element_Offset>Element_Size)
-        Element_Offset=Element_Size;
     size_t BS_Size;
     if (Buffer_Offset+Element_Size<=Buffer_Size)
         BS_Size=(size_t)(Element_Size-Element_Offset);
+    else if (Buffer_Offset+Element_Offset<=Buffer_Size)
+        BS_Size=Buffer_Size-(size_t)(Buffer_Offset+Element_Offset);
     else
-        BS_Size=Buffer_Size-(Buffer_Offset+(size_t)Element_Offset);
+        BS_Size=0;
+
     BT->Attach(Buffer+Buffer_Offset+(size_t)Element_Offset, BS_Size);
 }
 
@@ -166,14 +157,7 @@ void File__Analyze::Get_B3(int32u &Info, const char* Name)
     INTEGRITY_SIZE_ATLEAST_INT(3);
     Info=BigEndian2int24u(Buffer+Buffer_Offset+(size_t)Element_Offset);
     if (Trace_Activated)
-    {
-        Ztring Pos1; Pos1.From_Number(Info, 16);
-        Ztring Temp;
-        Temp.resize(6-Pos1.size(), __T('0'));
-        Temp.append(Pos1);
-        Temp.MakeUpperCase();
-        Param(Name, Ztring::ToZtring(Info)+__T(" (0x")+Temp+__T(")"));
-    }
+        Param(Name, Info, 24);
     Element_Offset+=3;
 }
 
@@ -183,14 +167,7 @@ void File__Analyze::Get_B4(int32u &Info, const char* Name)
     INTEGRITY_SIZE_ATLEAST_INT(4);
     Info=BigEndian2int32u(Buffer+Buffer_Offset+(size_t)Element_Offset);
     if (Trace_Activated)
-    {
-        Ztring Pos1; Pos1.From_Number(Info, 16);
-        Ztring Temp;
-        Temp.resize(8-Pos1.size(), __T('0'));
-        Temp.append(Pos1);
-        Temp.MakeUpperCase();
-        Param(Name, Ztring::ToZtring(Info)+__T(" (0x")+Temp+__T(")"));
-    }
+        Param(Name, Info);
     Element_Offset+=4;
 }
 
@@ -241,6 +218,44 @@ void File__Analyze::Get_B16(int128u &Info, const char* Name)
     Element_Offset+=16;
 }
 
+//---------------------------------------------------------------------------
+// Big Endian - float 16 bits
+// TODO: remove it when Linux version of ZenLib is updated
+float32 BigEndian2float16corrected(const char* Liste)
+{
+    //sign          1 bit
+    //exponent      5 bit
+    //significand  10 bit
+
+    //Retrieving data
+    int16u Integer=BigEndian2int16u(Liste);
+
+    //Retrieving elements
+    bool   Sign    =(Integer&0x8000)?true:false;
+    int32u Exponent=(Integer>>10)&0xFF;
+    int32u Mantissa= Integer&0x03FF;
+
+    //Some computing
+    if (Exponent==0 || Exponent==0xFF)
+        return 0; //These are denormalised numbers, NANs, and other horrible things
+    Exponent-=0x0F; //Bias
+    float64 Answer=(((float64)Mantissa)/8388608+1.0)*std::pow((float64)2, (int)Exponent); //(1+Mantissa) * 2^Exponent
+    if (Sign)
+        Answer=-Answer;
+
+    return (float32)Answer;
+}
+inline float32 BigEndian2float16corrected  (const int8u* List) {return BigEndian2float16corrected   ((const char*)List);}
+
+//---------------------------------------------------------------------------
+void File__Analyze::Get_BF2(float32 &Info, const char* Name)
+{
+    INTEGRITY_SIZE_ATLEAST_INT(2);
+    Info=BigEndian2float16corrected(Buffer+Buffer_Offset+(size_t)Element_Offset);
+    if (Trace_Activated) Param(Name, Info);
+    Element_Offset+=2;
+}
+
 //---------------------------------------------------------------------------
 void File__Analyze::Get_BF4(float32 &Info, const char* Name)
 {
@@ -269,7 +284,7 @@ void File__Analyze::Get_BF10(float80 &Info, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_BFP4(size_t Bits, float32 &Info, const char* Name)
+void File__Analyze::Get_BFP4(int8u Bits, float32 &Info, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST_INT(4);
     BS_Begin();
@@ -370,12 +385,7 @@ void File__Analyze::Skip_B3(const char* Name)
     if (Trace_Activated)
     {
         int32u Info=BigEndian2int24u(Buffer+Buffer_Offset+(size_t)Element_Offset);
-        Ztring Pos1; Pos1.From_Number(Info, 16);
-        Ztring Temp;
-        Temp.resize(6-Pos1.size(), __T('0'));
-        Temp.append(Pos1);
-        Temp.MakeUpperCase();
-        Param(Name, Ztring::ToZtring(Info)+__T(" (0x")+Temp+__T(")"));
+        Param(Name, Info, 24);
     }
     Element_Offset+=3;
 }
@@ -387,12 +397,7 @@ void File__Analyze::Skip_B4(const char* Name)
     if (Trace_Activated)
     {
         int32u Info=BigEndian2int32u(Buffer+Buffer_Offset+(size_t)Element_Offset);
-        Ztring Pos1; Pos1.From_Number(Info, 16);
-        Ztring Temp;
-        Temp.resize(8-Pos1.size(), __T('0'));
-        Temp.append(Pos1);
-        Temp.MakeUpperCase();
-        Param(Name, Ztring::ToZtring(Info)+__T(" (0x")+Temp+__T(")"));
+        Param(Name, Info);
     }
     Element_Offset+=4;
 }
@@ -446,7 +451,7 @@ void File__Analyze::Skip_BF4(const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_BFP4(size_t Bits, const char* Name)
+void File__Analyze::Skip_BFP4(int8u Bits, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST(4);
     BS_Begin();
@@ -642,12 +647,7 @@ void File__Analyze::Skip_L3(const char* Name)
     if (Trace_Activated)
     {
         int32u Info=LittleEndian2int24u(Buffer+Buffer_Offset+(size_t)Element_Offset);
-        Ztring Pos1; Pos1.From_Number(Info, 16);
-        Ztring Temp;
-        Temp.resize(6-Pos1.size(), __T('0'));
-        Temp.append(Pos1);
-        Temp.MakeUpperCase();
-        Param(Name, Ztring::ToZtring(Info)+__T(" (0x")+Temp+__T(")"));
+        Param(Name, Info, 24);
     }
     Element_Offset+=3;
 }
@@ -659,12 +659,7 @@ void File__Analyze::Skip_L4(const char* Name)
     if (Trace_Activated)
     {
         int32u Info=LittleEndian2int32u(Buffer+Buffer_Offset+(size_t)Element_Offset);
-        Ztring Pos1; Pos1.From_Number(Info, 16);
-        Ztring Temp;
-        Temp.resize(8-Pos1.size(), __T('0'));
-        Temp.append(Pos1);
-        Temp.MakeUpperCase();
-        Param(Name, Ztring::ToZtring(Info)+__T(" (0x")+Temp+__T(")"));
+        Param(Name, Info);
     }
     Element_Offset+=4;
 }
@@ -893,12 +888,7 @@ void File__Analyze::Skip_D3(const char* Name)
     if (Trace_Activated)
     {
         int32u Info=LittleEndian2int24u(Buffer+Buffer_Offset+(size_t)Element_Offset);
-        Ztring Pos1; Pos1.From_Number(Info, 16);
-        Ztring Temp;
-        Temp.resize(6-Pos1.size(), __T('0'));
-        Temp.append(Pos1);
-        Temp.MakeUpperCase();
-        Param(Name, Ztring::ToZtring(Info)+__T(" (0x")+Temp+__T(")"));
+        Param(Name, Info, 24);
     }
     Element_Offset+=6;
 }
@@ -910,12 +900,7 @@ void File__Analyze::Skip_D4(const char* Name)
     if (Trace_Activated)
     {
         int32u Info=LittleEndian2int32u(Buffer+Buffer_Offset+(size_t)Element_Offset);
-        Ztring Pos1; Pos1.From_Number(Info, 16);
-        Ztring Temp;
-        Temp.resize(8-Pos1.size(), __T('0'));
-        Temp.append(Pos1);
-        Temp.MakeUpperCase();
-        Param(Name, Ztring::ToZtring(Info)+__T(" (0x")+Temp+__T(")"));
+        Param(Name, Info);
     }
     Element_Offset+=8;
 }
@@ -1020,7 +1005,7 @@ void File__Analyze::Get_EB(int64u &Info, const char* Name)
         Element_Offset++;
         return;
     }
-    int32u Size=0;
+    int8u Size=0;
     int32u Size_Mark=0;
     BS_Begin();
     while (Size_Mark==0 && BS->Remain() && Size<=8)
@@ -1103,7 +1088,7 @@ void File__Analyze::Get_EB(int64u &Info, const char* Name)
                  break;
     }
 
-    if (Trace_Activated) Param(Name, Info);
+    if (Trace_Activated) Param(Name, Info, Size * 7);
     Element_Offset+=Size;
 }
 
@@ -1112,7 +1097,7 @@ void File__Analyze::Get_ES(int64s &Info, const char* Name)
 {
     //Element size
     INTEGRITY_SIZE_ATLEAST_INT(1);
-    int32u Size=0;
+    int8u Size=0;
     int32u Size_Mark=0;
     BS_Begin();
     while (Size_Mark==0 && BS->Remain() && Size<=8)
@@ -1480,8 +1465,8 @@ void File__Analyze::Get_VL_Prepare(vlc_fast &Vlc)
         if (Vlc.Vlc[Pos].bit_increment==255)
             break;
         Increment+=Vlc.Vlc[Pos].bit_increment;
-        size_t Value=Vlc.Vlc[Pos].value<<(Vlc.Size-Increment);
-        size_t ToFill_Size=1<<(Vlc.Size-Increment);
+        size_t Value=((size_t)Vlc.Vlc[Pos].value)<<(Vlc.Size-Increment);
+        size_t ToFill_Size=((size_t)1)<<(Vlc.Size-Increment);
         for (size_t ToFill_Pos=0; ToFill_Pos<ToFill_Size; ToFill_Pos++)
         {
             Vlc.Array[Value+ToFill_Pos]=Pos;
@@ -1686,6 +1671,119 @@ void File__Analyze::Get_Local(int64u Bytes, Ztring &Info, const char* Name)
     Element_Offset+=Bytes;
 }
 
+//---------------------------------------------------------------------------
+extern const wchar_t ISO_6937_2_Tables[];
+void File__Analyze::Get_ISO_6937_2(int64u Bytes, Ztring &Info, const char* Name)
+{
+    INTEGRITY_SIZE_ATLEAST_STRING(Bytes);
+    Info.clear();
+    size_t End = Buffer_Offset + (size_t)Element_Offset + (size_t)Bytes;
+    for (size_t Pos=Buffer_Offset+(size_t)Element_Offset; Pos<End; ++Pos)
+    {
+        wchar_t EscapeChar=L'\x0000';
+        wchar_t NewChar=L'\x0000';
+        switch (Buffer[Pos])
+        {
+            case 0xA9 :    NewChar=L'\x2018'; break;
+            case 0xAA :    NewChar=L'\x201C'; break;
+            case 0xAC :    NewChar=L'\x2190'; break;
+            case 0xAD :    NewChar=L'\x2191'; break;
+            case 0xAE :    NewChar=L'\x2192'; break;
+            case 0xAF :    NewChar=L'\x2193'; break;
+            case 0xB4 :    NewChar=L'\x00D7'; break;
+            case 0xB8 :    NewChar=L'\x00F7'; break;
+            case 0xB9 :    NewChar=L'\x2019'; break;
+            case 0xBA :    NewChar=L'\x201D'; break;
+            case 0xC1 : EscapeChar=L'\x0300'; break;
+            case 0xC2 : EscapeChar=L'\x0301'; break;
+            case 0xC3 : EscapeChar=L'\x0302'; break;
+            case 0xC4 : EscapeChar=L'\x0303'; break;
+            case 0xC5 : EscapeChar=L'\x0304'; break;
+            case 0xC6 : EscapeChar=L'\x0306'; break;
+            case 0xC7 : EscapeChar=L'\x0307'; break;
+            case 0xC8 : EscapeChar=L'\x0308'; break;
+            case 0xCA : EscapeChar=L'\x030A'; break;
+            case 0xCB : EscapeChar=L'\x0327'; break;
+            case 0xCD : EscapeChar=L'\x030B'; break;
+            case 0xCE : EscapeChar=L'\x0328'; break;
+            case 0xCF : EscapeChar=L'\x030C'; break;
+            case 0xD0 :    NewChar=L'\x2015'; break;
+            case 0xD1 :    NewChar=L'\x00B9'; break;
+            case 0xD2 :    NewChar=L'\x00AE'; break;
+            case 0xD3 :    NewChar=L'\x00A9'; break;
+            case 0xD4 :    NewChar=L'\x2122'; break;
+            case 0xD5 :    NewChar=L'\x266A'; break;
+            case 0xD6 :    NewChar=L'\x00AC'; break;
+            case 0xD7 :    NewChar=L'\x00A6'; break;
+            case 0xDC :    NewChar=L'\x215B'; break;
+            case 0xDD :    NewChar=L'\x215C'; break;
+            case 0xDE :    NewChar=L'\x215D'; break;
+            case 0xDF :    NewChar=L'\x215E'; break;
+            case 0xE0 :    NewChar=L'\x2126'; break;
+            case 0xE1 :    NewChar=L'\x00C6'; break;
+            case 0xE2 :    NewChar=L'\x0110'; break;
+            case 0xE3 :    NewChar=L'\x00AA'; break;
+            case 0xE4 :    NewChar=L'\x0126'; break;
+            case 0xE6 :    NewChar=L'\x0132'; break;
+            case 0xE7 :    NewChar=L'\x013F'; break;
+            case 0xE8 :    NewChar=L'\x0141'; break;
+            case 0xE9 :    NewChar=L'\x00D8'; break;
+            case 0xEA :    NewChar=L'\x0152'; break;
+            case 0xEB :    NewChar=L'\x00BA'; break;
+            case 0xEC :    NewChar=L'\x00DE'; break;
+            case 0xED :    NewChar=L'\x0166'; break;
+            case 0xEE :    NewChar=L'\x014A'; break;
+            case 0xEF :    NewChar=L'\x0149'; break;
+            case 0xF0 :    NewChar=L'\x0138'; break;
+            case 0xF1 :    NewChar=L'\x00E6'; break;
+            case 0xF2 :    NewChar=L'\x0111'; break;
+            case 0xF3 :    NewChar=L'\x00F0'; break;
+            case 0xF4 :    NewChar=L'\x0127'; break;
+            case 0xF5 :    NewChar=L'\x0131'; break;
+            case 0xF6 :    NewChar=L'\x0133'; break;
+            case 0xF7 :    NewChar=L'\x0140'; break;
+            case 0xF8 :    NewChar=L'\x0142'; break;
+            case 0xF9 :    NewChar=L'\x00F8'; break;
+            case 0xFA :    NewChar=L'\x0153'; break;
+            case 0xFB :    NewChar=L'\x0153'; break;
+            case 0xFC :    NewChar=L'\x00FE'; break;
+            case 0xFD :    NewChar=L'\x00FE'; break;
+            case 0xFE :    NewChar=L'\x014B'; break;
+            case 0xFF :    NewChar=L'\x00AD'; break;
+            case 0xC0 :
+            case 0xC9 :
+            case 0xCC :
+            case 0xD8 :
+            case 0xD9 :
+            case 0xDA :
+            case 0xDB :
+            case 0xE5 :
+                                                 break;
+            default  : NewChar=(Char)(Buffer[Pos]);
+        }
+
+        if (EscapeChar)
+        {
+            if (Pos+1<End)
+            {
+                if (Buffer[Pos]>=0xC0 && Buffer[Pos]<=0xCF && Buffer[Pos+1]>=0x40 && Buffer[Pos+1]<=0x7F)
+                    Info+=Ztring().From_Unicode(ISO_6937_2_Tables[((Buffer[Pos]-0xC0))*0x40+(Buffer[Pos+1]-0x40)]);
+                else
+                {
+                Info+=(Char)(Buffer[Pos+1]);
+                Info+=Ztring().From_Unicode(&EscapeChar, 1); //(EscapeChar) after new ZenLib release
+                }
+                EscapeChar=__T('\x0000');
+                Pos++;
+            }
+        }
+        else if (NewChar)
+            Info+=Ztring().From_Unicode(&NewChar, 1); //(NewChar) after new ZenLib release
+    }
+    if (Trace_Activated && Bytes) Param(Name, Info);
+    Element_Offset+=Bytes;
+}
+
 //---------------------------------------------------------------------------
 void File__Analyze::Get_ISO_8859_1(int64u Bytes, Ztring &Info, const char* Name)
 {
@@ -1704,6 +1802,30 @@ void File__Analyze::Get_ISO_8859_2(int64u Bytes, Ztring &Info, const char* Name)
     Element_Offset+=Bytes;
 }
 
+//---------------------------------------------------------------------------
+void File__Analyze::Get_ISO_8859_5(int64u Bytes, Ztring &Info, const char* Name)
+{
+    INTEGRITY_SIZE_ATLEAST_STRING(Bytes);
+    Info.clear();
+    size_t End = Buffer_Offset + (size_t)Element_Offset + (size_t)Bytes;
+    for (size_t Pos=Buffer_Offset+(size_t)Element_Offset; Pos<End; ++Pos)
+    {
+        switch (Buffer[Pos])
+        {
+            case 0xAD : Info+=Ztring().From_Unicode(L"\xAD"); break; //L'\xAD' after new ZenLib release
+            case 0xF0 : Info+=Ztring().From_Unicode(L"\x2116"); break; //L'\x2116' after new ZenLib release
+            case 0xFD : Info+=Ztring().From_Unicode(L"\xA7"); break; //L'\xA7' after new ZenLib release
+            default   :
+                        {
+                        wchar_t NewChar=(Buffer[Pos]<=0xA0?0x0000:0x0360)+Buffer[Pos];
+                        Info+=Ztring().From_Unicode(&NewChar, 1); //(NewChar) after new ZenLib release
+                        }
+        }
+    }
+    if (Trace_Activated && Bytes) Param(Name, Info);
+    Element_Offset+=Bytes;
+}
+
 //---------------------------------------------------------------------------
 void File__Analyze::Get_String(int64u Bytes, std::string &Info, const char* Name)
 {
@@ -1771,6 +1893,19 @@ void File__Analyze::Skip_Local(int64u Bytes, const char* Name)
     Element_Offset+=Bytes;
 }
 
+//---------------------------------------------------------------------------
+void File__Analyze::Skip_ISO_6937_2(int64u Bytes, const char* Name)
+{
+    INTEGRITY_SIZE_ATLEAST(Bytes);
+    if (Trace_Activated && Bytes)
+    {
+        Ztring Temp;
+        Get_ISO_6937_2(Bytes, Temp, Name);
+    }
+    else
+        Element_Offset+=Bytes;
+}
+
 //---------------------------------------------------------------------------
 void File__Analyze::Skip_String(int64u Bytes, const char* Name)
 {
@@ -1845,7 +1980,7 @@ void File__Analyze::Get_Flags (int64u Flags, size_t Order, bool &Info, const cha
         Info=false;
 
     Element_Begin0();
-    if (Trace_Activated) Param(Name, Info?"Yes":"No");
+    if (Trace_Activated && MediaInfoLib::Config.Trace_Format_Get()!=MediaInfoLib::Config.Trace_Format_XML && MediaInfoLib::Config.Trace_Format_Get()!=MediaInfoLib::Config.Trace_Format_MICRO_XML) Param(Name, Info);
     Element_End0();
 }
 
@@ -1855,7 +1990,7 @@ void File__Analyze::Get_Flags (int64u ValueToPut, int8u &Info, const char* Name)
     Info=(int8u)ValueToPut;
 
     Element_Begin0();
-    if (Trace_Activated) Param(Name, Info);
+    if (Trace_Activated && MediaInfoLib::Config.Trace_Format_Get()!=MediaInfoLib::Config.Trace_Format_XML && MediaInfoLib::Config.Trace_Format_Get()!=MediaInfoLib::Config.Trace_Format_MICRO_XML) Param(Name, Info);
     Element_End0();
 }
 
@@ -1863,7 +1998,7 @@ void File__Analyze::Get_Flags (int64u ValueToPut, int8u &Info, const char* Name)
 void File__Analyze::Skip_Flags(int64u Flags, size_t Order, const char* Name)
 {
     Element_Begin0();
-    if (Trace_Activated) Param(Name, (Flags&((int64u)1<<Order))?"Yes":"No");
+    if (Trace_Activated && MediaInfoLib::Config.Trace_Format_Get()!=MediaInfoLib::Config.Trace_Format_XML && MediaInfoLib::Config.Trace_Format_Get()!=MediaInfoLib::Config.Trace_Format_MICRO_XML) Param(Name, (Flags&((int64u)1<<Order))); //TODO: support flags in XML trace
     Element_End0();
 }
 
@@ -1871,7 +2006,7 @@ void File__Analyze::Skip_Flags(int64u Flags, size_t Order, const char* Name)
 void File__Analyze::Skip_Flags(int64u ValueToPut, const char* Name)
 {
     Element_Begin0();
-    if (Trace_Activated) Param(Name, ValueToPut);
+    if (Trace_Activated && MediaInfoLib::Config.Trace_Format_Get()!=MediaInfoLib::Config.Trace_Format_XML && MediaInfoLib::Config.Trace_Format_Get()!=MediaInfoLib::Config.Trace_Format_MICRO_XML) Param(Name, ValueToPut);
     Element_End0();
 }
 
@@ -1880,7 +2015,7 @@ void File__Analyze::Skip_Flags(int64u ValueToPut, const char* Name)
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_BS(size_t Bits, int32u &Info, const char* Name)
+void File__Analyze::Get_BS(int8u Bits, int32u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get4(Bits);
@@ -1896,75 +2031,119 @@ void File__Analyze::Get_SB(             bool &Info, const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S1(size_t Bits, int8u &Info, const char* Name)
+void File__Analyze::Get_S1(int8u Bits, int8u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get1(Bits);
-    if (Trace_Activated)
-    {
-        Param(Name, Info);
-        Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
-    }
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S2(size_t Bits, int16u &Info, const char* Name)
+void File__Analyze::Get_S2(int8u Bits, int16u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get2(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S3(size_t Bits, int32u &Info, const char* Name)
+void File__Analyze::Get_S3(int8u Bits, int32u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get4(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S4(size_t Bits, int32u &Info, const char* Name)
+void File__Analyze::Get_S4(int8u Bits, int32u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get4(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S5(size_t Bits, int64u &Info, const char* Name)
+void File__Analyze::Get_S5(int8u Bits, int64u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get8(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S6(size_t Bits, int64u &Info, const char* Name)
+void File__Analyze::Get_S6(int8u Bits, int64u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get8(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S7(size_t Bits, int64u &Info, const char* Name)
+void File__Analyze::Get_S7(int8u Bits, int64u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get8(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Get_S8(size_t Bits, int64u &Info, const char* Name)
+void File__Analyze::Get_S8(int8u Bits, int64u &Info, const char* Name)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Get8(Bits);
-    if (Trace_Activated) Param(Name, Info);
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, Info);
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+    #endif //MEDIAINFO_TRACE
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_BS(size_t Bits, int32u &Info)
+void File__Analyze::Peek_BS(int8u Bits, int32u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek4(Bits);
@@ -1978,56 +2157,56 @@ void File__Analyze::Peek_SB(              bool &Info)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S1(size_t Bits, int8u &Info)
+void File__Analyze::Peek_S1(int8u Bits, int8u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek1(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S2(size_t Bits, int16u &Info)
+void File__Analyze::Peek_S2(int8u Bits, int16u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek2(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S3(size_t Bits, int32u &Info)
+void File__Analyze::Peek_S3(int8u Bits, int32u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek4(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S4(size_t Bits, int32u &Info)
+void File__Analyze::Peek_S4(int8u Bits, int32u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek4(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S5(size_t Bits, int64u &Info)
+void File__Analyze::Peek_S5(int8u Bits, int64u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek8(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S6(size_t Bits, int64u &Info)
+void File__Analyze::Peek_S6(int8u Bits, int64u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek8(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S7(size_t Bits, int64u &Info)
+void File__Analyze::Peek_S7(int8u Bits, int64u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek8(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Peek_S8(size_t Bits, int64u &Info)
+void File__Analyze::Peek_S8(int8u Bits, int64u &Info)
 {
     INTEGRITY_INT(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
     Info=BS->Peek8(Bits);
@@ -2040,7 +2219,7 @@ void File__Analyze::Skip_BS(size_t Bits, const char* Name)
     if (Trace_Activated)
     {
         if (Bits<=32) //TODO: in BitStream.h, handle >32 bit gets
-            Param(Name, BS->Get4(Bits));
+            Param(Name, BS->Get4((int8u)Bits));
         else
         {
             Param(Name, "(Data)");
@@ -2062,85 +2241,122 @@ void File__Analyze::Skip_SB(              const char* Name)
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S1(size_t Bits, const char* Name)
+void File__Analyze::Skip_S1(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-    {
-        Param(Name, BS->Get1(Bits));
-        Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
-    }
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get1(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S2(size_t Bits, const char* Name)
+void File__Analyze::Skip_S2(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get2(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get2(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S3(size_t Bits, const char* Name)
+void File__Analyze::Skip_S3(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get4(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get4(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S4(size_t Bits, const char* Name)
+void File__Analyze::Skip_S4(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get4(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get4(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S5(size_t Bits, const char* Name)
+void File__Analyze::Skip_S5(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get8(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get8(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S6(size_t Bits, const char* Name)
+void File__Analyze::Skip_S6(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get8(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get8(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S7(size_t Bits, const char* Name)
+void File__Analyze::Skip_S7(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get8(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get8(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
 //---------------------------------------------------------------------------
-void File__Analyze::Skip_S8(size_t Bits, const char* Name)
+void File__Analyze::Skip_S8(int8u Bits, const char* Name)
 {
     INTEGRITY(Bits<=BS->Remain(), "Size is wrong", BS->Offset_Get())
-    if (Trace_Activated)
-        Param(Name, BS->Get8(Bits));
-    else
+    #if MEDIAINFO_TRACE
+        if (Trace_Activated)
+        {
+            Param(Name, BS->Get8(Bits));
+            Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        }
+        else
+    #endif //MEDIAINFO_TRACE
         BS->Skip(Bits);
 }
 
@@ -2219,8 +2435,8 @@ void File__Analyze::Get_T1(size_t Bits, int8u &Info, const char* Name)
     Info=BT->Get1(Bits);
     if (Trace_Activated)
     {
-        Param(Name, Info);
         Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        Param(Name, Info);
     }
 }
 
@@ -2324,8 +2540,8 @@ void File__Analyze::Skip_T1(size_t Bits, const char* Name)
     INTEGRITY(Bits<=BT->Remain(), "Size is wrong", BT->Offset_Get())
     if (Trace_Activated)
     {
-        Param(Name, BT->Get1(Bits));
         Param_Info(__T("(")+Ztring::ToZtring(Bits)+__T(" bits)"));
+        Param(Name, BT->Get1(Bits));
     }
     else
         BT->Skip1(Bits);
