@@ -105,8 +105,8 @@
         _TOAPPEND; \
         Debug_Close();
 #else // MEDIAINFO_DEBUG
-    #define MEDIAINFO_DEBUG1(_NAME,__TOAPPEND)
-    #define MEDIAINFO_DEBUG2(_NAME,__TOAPPEND)
+    #define MEDIAINFO_DEBUG1(_NAME,_TOAPPEND)
+    #define MEDIAINFO_DEBUG2(_NAME,_TOAPPEND)
 #endif // MEDIAINFO_DEBUG
 
 //---------------------------------------------------------------------------
@@ -117,6 +117,9 @@
 #include "ZenLib/ZtringListListF.h"
 #include "ZenLib/File.h"
 #include <algorithm>
+#if defined(MEDIAINFO_LIBCURL_YES)
+    #include "MediaInfo/Reader/Reader_libcurl.h"
+#endif //defined(MEDIAINFO_LIBCURL_YES)
 using namespace ZenLib;
 using namespace std;
 //---------------------------------------------------------------------------
@@ -125,7 +128,7 @@ namespace MediaInfoLib
 {
 
 //---------------------------------------------------------------------------
-const Char*  MediaInfo_Version=__T("MediaInfoLib - v0.7.89");
+const Char*  MediaInfo_Version=__T("MediaInfoLib - v0.7.92.1");
 const Char*  MediaInfo_Url=__T("http://MediaArea.net/MediaInfo");
       Ztring EmptyZtring;       //Use it when we can't return a reference to a true Ztring
 const Ztring EmptyZtring_Const; //Use it when we can't return a reference to a true Ztring, const version
@@ -203,6 +206,9 @@ void MediaInfo_Config::Init()
         MpegTs_VbrDetection_Occurences=4;
         MpegTs_VbrDetection_GiveUp=false;
     #endif //MEDIAINFO_ADVANCED
+    #if MEDIAINFO_ADVANCED
+        Format_Profile_Split=false;
+    #endif //MEDIAINFO_ADVANCED
     Complete=0;
     BlockMethod=0;
     Internet=0;
@@ -240,6 +246,9 @@ void MediaInfo_Config::Init()
         Ssh_IgnoreSecurity=false;
         Ssl_IgnoreSecurity=false;
     #endif //defined(MEDIAINFO_LIBCURL_YES)
+    #if MEDIAINFO_FIXITY
+        TryToFix=false;
+    #endif //MEDIAINFO_FIXITY
 
     CS.Leave();
 
@@ -885,6 +894,23 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
         CustomMapping_Set(Value);
         return Ztring();
     }
+    else if (Option_Lower==__T("format_profile_split"))
+    {
+        #if MEDIAINFO_ADVANCED
+            Format_Profile_Split_Set(Value.To_int8u()?true:false);
+            return Ztring();
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("format_profile_split_get"))
+    {
+        #if MEDIAINFO_ADVANCED
+            return Format_Profile_Split_Get()?__T("1"):__T("0");;
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
     else if (Option_Lower==__T("event_callbackfunction"))
     {
         #if MEDIAINFO_EVENTS
@@ -902,6 +928,14 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
             return __T("Libcurl support is disabled due to compilation options");
         #endif // defined(MEDIAINFO_LIBCURL_YES)
     }
+    else if (Option_Lower==__T("info_canhandleurls"))
+    {
+        #if defined(MEDIAINFO_LIBCURL_YES)
+            return CanHandleUrls()?__T("1"):__T("0");;
+        #else // defined(MEDIAINFO_LIBCURL_YES)
+            return __T("Libcurl support is disabled due to compilation options");
+        #endif // defined(MEDIAINFO_LIBCURL_YES)
+    }
     else if (Option_Lower==__T("ssh_publickeyfilename"))
     {
         #if defined(MEDIAINFO_LIBCURL_YES)
@@ -1001,6 +1035,15 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
             return __T("Libcurl support is disabled due to compilation options");
         #endif // defined(MEDIAINFO_LIBCURL_YES)
     }
+    else if (Option_Lower==__T("trytofix"))
+    {
+        #if MEDIAINFO_FIXITY
+            TryToFix_Set(!(Value==__T("0") || Value.empty()));
+            return Ztring();
+        #else //MEDIAINFO_FIXITY
+            return __T("Fixity support is disabled due to compilation options");
+        #endif //MEDIAINFO_FIXITY
+    }
     else
         return __T("Option not known");
 }
@@ -1497,7 +1540,7 @@ void MediaInfo_Config::Language_Set (stream_t StreamKind)
             ToReplace.FindAndReplace(__T("/String9"), Ztring());
             ToReplace.FindAndReplace(__T("/String"),  Ztring());
         }
-        if (!Language_Raw && ToReplace.find(__T("/"))!=Error) //Complex values, like XXX/YYY --> We translate both XXX and YYY
+        if (!Language_Raw && ToReplace.find(__T('/'))!=Error) //Complex values, like XXX/YYY --> We translate both XXX and YYY
         {
             Ztring ToReplace1=ToReplace.SubString(Ztring(), __T("/"));
             Ztring ToReplace2=ToReplace.SubString(__T("/"), Ztring());
@@ -2372,6 +2415,24 @@ bool MediaInfo_Config::CustomMapping_IsPresent(const Ztring &Format, const Ztrin
     return true;
 }
 
+//***************************************************************************
+// Report changes
+//***************************************************************************
+
+#if MEDIAINFO_ADVANCED
+void MediaInfo_Config::Format_Profile_Split_Set(bool Value)
+{
+    CriticalSectionLocker CSL(CS);
+    Format_Profile_Split=Value;
+}
+
+bool MediaInfo_Config::Format_Profile_Split_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return Format_Profile_Split;
+}
+#endif // MEDIAINFO_ADVANCED
+
 //***************************************************************************
 // Event
 //***************************************************************************
@@ -2433,7 +2494,15 @@ void MediaInfo_Config::Event_Send (const int8u* Data_Content, size_t Data_Size)
     CriticalSectionLocker CSL(CS);
 
     if (Event_CallBackFunction)
+    {
+        MEDIAINFO_DEBUG1(   "Event",
+                            Debug+=", EventID=";Debug+=Ztring::ToZtring(LittleEndian2int32u(Data_Content), 16).To_UTF8();)
+
         Event_CallBackFunction ((unsigned char*)Data_Content, Data_Size, Event_UserHandler);
+
+        MEDIAINFO_DEBUG2(   "Event",
+                            )
+    }
 }
 #endif //MEDIAINFO_EVENTS
 
@@ -2481,6 +2550,12 @@ void MediaInfo_Config::Log_Send (int8u Type, int8u Severity, int32u MessageCode,
 //***************************************************************************
 
 #if defined(MEDIAINFO_LIBCURL_YES)
+bool MediaInfo_Config::CanHandleUrls()
+{
+    CriticalSectionLocker CSL(CS);
+    return Reader_libcurl::Load();
+}
+
 void MediaInfo_Config::Ssh_PublicKeyFileName_Set (const Ztring &Value)
 {
     CriticalSectionLocker CSL(CS);
@@ -2627,7 +2702,22 @@ bool MediaInfo_Config::Ssl_IgnoreSecurity_Get ()
     CriticalSectionLocker CSL(CS);
     return Ssl_IgnoreSecurity;
 }
-
 #endif //defined(MEDIAINFO_LIBCURL_YES)
 
+
+#if MEDIAINFO_FIXITY
+//---------------------------------------------------------------------------
+void MediaInfo_Config::TryToFix_Set (bool NewValue)
+{
+    CriticalSectionLocker CSL(CS);
+    TryToFix=NewValue;
+}
+
+bool MediaInfo_Config::TryToFix_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return TryToFix;
+}
+#endif //MEDIAINFO_FIXITY
+
 } //NameSpace
