@@ -930,6 +930,12 @@ size_t MediaInfo_Internal::Open_Buffer_Finalize ()
     {
         delete[] Config.File_Buffer; Config.File_Buffer=NULL; Config.File_Buffer_Size=0; Config.File_Buffer_Size_Max=0;
     }
+    #if MEDIAINFO_EVENTS
+        if (!Config.File_IsReferenced_Get()) //TODO: get its own metadata in order to know if it was created by this instance
+        {
+            delete Config.Config_PerPackage; Config.Config_PerPackage=NULL;
+        }
+    #endif //MEDIAINFO_EVENTS
 
     EXECUTE_SIZE_T(1, Debug+=__T("Open_Buffer_Finalize, will return 1"))
 }
@@ -1208,8 +1214,8 @@ String MediaInfo_Internal::Option (const String &Option, const String &Value)
     CriticalSectionLocker CSL(CS);
     MEDIAINFO_DEBUG_CONFIG_TEXT(Debug+=__T("Option, Option=");Debug+=Ztring(Option);Debug+=__T(", Value=");Debug+=Ztring(Value);)
     Ztring OptionLower=Option; OptionLower.MakeLowerCase();
-         if (Option.empty())
-        return __T("");
+    if (Option.empty())
+        return String();
     else if (OptionLower==__T("language_update"))
     {
         if (!Info || Info->Get(Stream_General, 0, __T("CompleteName"))==__T(""))
@@ -1274,22 +1280,22 @@ String MediaInfo_Internal::Option (const String &Option, const String &Value)
                     Ztring FrameNumberZ=List[Pos].substr(List[Pos].find(__T("Frame="))+6, string::npos);
                     SeekValue=FrameNumberZ.To_int64u();
                 }
-                else if (!List[Pos].empty() && List[Pos].find(__T(":"))!=string::npos)
+                else if (!List[Pos].empty() && List[Pos].find(__T(':'))!=string::npos)
                 {
                     Method=2;
                     Ztring ValueZ=List[Pos];
                     SeekValue=0;
-                    size_t Value_Pos=ValueZ.find(__T(":"));
+                    size_t Value_Pos=ValueZ.find(__T(':'));
                     if (Value_Pos==string::npos)
                         Value_Pos=ValueZ.size();
                     SeekValue+=Ztring(ValueZ.substr(0, Value_Pos)).To_int64u()*60*60*1000*1000*1000;
                     ValueZ.erase(0, Value_Pos+1);
-                    Value_Pos=ValueZ.find(__T(":"));
+                    Value_Pos=ValueZ.find(__T(':'));
                     if (Value_Pos==string::npos)
                         Value_Pos=ValueZ.size();
                     SeekValue+=Ztring(ValueZ.substr(0, Value_Pos)).To_int64u()*60*1000*1000*1000;
                     ValueZ.erase(0, Value_Pos+1);
-                    Value_Pos=ValueZ.find(__T("."));
+                    Value_Pos=ValueZ.find(__T('.'));
                     if (Value_Pos==string::npos)
                         Value_Pos=ValueZ.size();
                     SeekValue+=Ztring(ValueZ.substr(0, Value_Pos)).To_int64u()*1000*1000*1000;
