@@ -25,7 +25,6 @@
 #include <vector>
 #include <set>
 #include <bitset>
-using namespace std;
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -82,9 +81,9 @@ protected :
     void Streams_Finish_Essence_FillID (int32u EssenceUID, int128u TrackUID);
     void Streams_Finish_Descriptor (const int128u DescriptorUID, const int128u PackageUID);
     void Streams_Finish_Locator (const int128u DescriptorUID, const int128u LocatorUID);
-    void Streams_Finish_Component (const int128u ComponentUID, float64 EditRate, int32u TrackID, int64u Origin);
-    void Streams_Finish_Component_ForTimeCode (const int128u ComponentUID, float64 EditRate, int32u TrackID, int64u Origin, bool IsSourcePackage);
-    void Streams_Finish_Component_ForAS11 (const int128u ComponentUID, float64 EditRate, int32u TrackID, int64u Origin);
+    void Streams_Finish_Component (const int128u ComponentUID, float64 EditRate, int32u TrackID, int64s Origin);
+    void Streams_Finish_Component_ForTimeCode (const int128u ComponentUID, float64 EditRate, int32u TrackID, int64s Origin, bool IsSourcePackage);
+    void Streams_Finish_Component_ForAS11 (const int128u ComponentUID, float64 EditRate, int32u TrackID, int64s Origin);
     void Streams_Finish_Identification (const int128u IdentificationUID);
     void Streams_Finish_CommercialNames ();
 
@@ -173,11 +172,12 @@ protected :
     void MCALabelSubDescriptor();
     void TimedTextDescriptor();
     void TimedTextResourceSubDescriptor();
-    void Unknown67SubDescriptor();
+    void ContainerConstraintsSubDescriptor();
     void Mpeg4VisualSubDescriptor();
     void AudioChannelLabelSubDescriptor();
     void SoundfieldGroupLabelSubDescriptor();
     void GroupOfSoundfieldGroupsLabelSubDescriptor();
+    void AVCSubDescriptor();
     void OpenIncompleteHeaderPartition();
     void ClosedIncompleteHeaderPartition();
     void OpenCompleteHeaderPartition();
@@ -192,7 +192,7 @@ protected :
     void ClosedCompleteFooterPartition();
     void Primer();
     void IndexTableSegment();
-    void RandomIndexMetadata();
+    void RandomIndexPack();
     void SDTI_SystemMetadataPack();
     void SDTI_PackageMetadataSet();
     void SDTI_PictureMetadataSet();
@@ -332,7 +332,7 @@ protected :
     void JPEG2000PictureSubDescriptor_CodingStyleDefault();     //
     void JPEG2000PictureSubDescriptor_QuantizationDefault();    //
     void MpegAudioDescriptor_BitRate();                         //
-    void MultipleDescriptor_SubDescriptorUIDs();                //3F01
+    void MultipleDescriptor_FileDescriptors();                  //3F01
     void PrimaryExtendedSpokenLanguage();                       //
     void SecondaryExtendedSpokenLanguage();                     //
     void OriginalExtendedSpokenLanguage();                      //
@@ -358,6 +358,21 @@ protected :
     void Mpeg4VisualDescriptor_BPictureCount() {MPEG2VideoDescriptor_BPictureCount();}
     void Mpeg4VisualDescriptor_ProfileAndLevel();               //
     void Mpeg4VisualDescriptor_BitRate() {MPEG2VideoDescriptor_BitRate();}
+    void AVCDescriptor_ConstantBFrames() {MPEG2VideoDescriptor_ConstantBFrames();}
+    void AVCDescriptor_CodedContentType() {MPEG2VideoDescriptor_CodedContentType();}
+    void AVCDescriptor_ClosedGOP() {MPEG2VideoDescriptor_ClosedGOP();}
+    void AVCDescriptor_IdenticalGOP() {MPEG2VideoDescriptor_IdenticalGOP();}
+    void AVCDescriptor_MaxGOP() {MPEG2VideoDescriptor_MaxGOP();}
+    void AVCDescriptor_BPictureCount() {MPEG2VideoDescriptor_BPictureCount();}
+    void AVCDescriptor_Profile();
+    void AVCDescriptor_MaximumBitRate();
+    void AVCDescriptor_ProfileConstraint();
+    void AVCDescriptor_Level();
+    void AVCDescriptor_DecodingDelay();
+    void AVCDescriptor_MaximumRefFrames();
+    void AVCDescriptor_SequenceParameterSetFlag();
+    void AVCDescriptor_PictureParameterSetFlag();
+    void AVCDescriptor_AverageBitRate();
     void NetworkLocator_URLString();                            //4001
     void Preface_LastModifiedDate();                            //3B02
     void Preface_ContentStorage();                              //3B03
@@ -549,33 +564,45 @@ protected :
     //TimeCode
     struct mxftimecode
     {
-        int16u  RoundedTimecodeBase;
         int64u  StartTimecode;
+        int16u  RoundedTimecodeBase;
         bool    DropFrame;
 
-        mxftimecode()
-            : RoundedTimecodeBase(0)
-            , StartTimecode((int64u)-1)
-            , DropFrame(false)
-        {
-        }
-
-        mxftimecode(int16u RoundedTimecodeBase_, int64u StartTimecode_, bool DropFrame_)
+        mxftimecode(int16u RoundedTimecodeBase_ = 0, int64u StartTimecode_ = (int64u)-1, bool DropFrame_ = false)
             : RoundedTimecodeBase(RoundedTimecodeBase_)
             , StartTimecode(StartTimecode_)
             , DropFrame(DropFrame_)
         {
         }
+        bool IsInit() const
+        {
+            return RoundedTimecodeBase && StartTimecode != (int64u)-1;
+        }
+        float64 Get_TimeCode_StartTimecode_Temp(const int64u& File_IgnoreEditsBefore) const
+        {
+            if (RoundedTimecodeBase)
+            {
+                float64 TimeCode_StartTimecode_Temp = ((float64)(StartTimecode + File_IgnoreEditsBefore)) / RoundedTimecodeBase;
+                if (DropFrame)
+                {
+                    TimeCode_StartTimecode_Temp *= 1001;
+                    TimeCode_StartTimecode_Temp /= 1000;
+                }
+                return TimeCode_StartTimecode_Temp;
+            }
+            else
+                return 0.0;
+        }
     };
 
     // Temp
-    struct randomindexmetadata
+    struct randomindexpack
     {
         int64u ByteOffset;
         int32u BodySID;
     };
-    std::vector<randomindexmetadata> RandomIndexMetadatas;
-    bool                             RandomIndexMetadatas_AlreadyParsed;
+    std::vector<randomindexpack>     RandomIndexPacks;
+    bool                             RandomIndexPacks_AlreadyParsed;
     std::set<int64u>                 PartitionPack_AlreadyParsed;
     size_t Streams_Count;
     int128u Code;
@@ -668,7 +695,7 @@ protected :
         int32u TrackNumber;
         float64 EditRate_Real; //Before demux adaptation
         float64 EditRate;
-        int64u  Origin;
+        int64s  Origin;
         bool   Stream_Finish_Done;
 
         track()
@@ -732,7 +759,7 @@ protected :
     };
     typedef std::map<int32u, essence> essences; //Key is TrackNumber
     essences Essences;
-    bitset<Stream_Max+1> StreamPos_StartAtZero; //information about the base of StreamPos (0 or 1, 1 is found in 1 file) TODO: per Essence code (last 4 bytes of the Essence header 0xTTXXTTXX)
+    std::bitset<Stream_Max+1> StreamPos_StartAtZero; //information about the base of StreamPos (0 or 1, 1 is found in 1 file) TODO: per Essence code (last 4 bytes of the Essence header 0xTTXXTTXX)
 
     //Descriptor
     struct descriptor
@@ -787,7 +814,9 @@ protected :
         bool HasMPEG2VideoDescriptor;
         bool IsAes3Descriptor;
         int32u ByteRate;
-
+        #if MEDIAINFO_ADVANCED
+            int16u Jpeg2000_Rsiz;
+        #endif //MEDIAINFO_ADVANCED
 
         //MCALabelSubDescriptor specific (including SoundfieldGroupLabelSubDescriptor...)
         int128u     MCALabelDictionaryID;
@@ -841,6 +870,9 @@ protected :
             HasMPEG2VideoDescriptor=false;
             IsAes3Descriptor=false;
             ByteRate=(int32u)-1;
+            #if MEDIAINFO_ADVANCED
+                Jpeg2000_Rsiz=(int16u)-1;
+            #endif //MEDIAINFO_ADVANCED
 
             //MCALabelSubDescriptor specific (including SoundfieldGroupLabelSubDescriptor...)
             MCALabelDictionaryID.hi=(int64u)-1;
@@ -855,6 +887,7 @@ protected :
     };
     typedef std::map<int128u, descriptor> descriptors; //Key is InstanceUID of Descriptor
     descriptors Descriptors;
+    void Descriptor_Fill(const char* Name, const Ztring& Value);
 
     //Locator
     struct locator
@@ -1053,6 +1086,7 @@ protected :
             CompletionDate=(int64u)-1;
             TextlessElementsExist=(int8u)-1;
             ProgrammeHasText=(int8u)-1;
+            FpaPass=(int8u)-1;
         }
 
         ~as11()
@@ -1106,14 +1140,14 @@ protected :
         inline void Locators_CleanUp() {}
         inline void Locators_Test() {}
     #endif //defined(MEDIAINFO_REFERENCES_YES)
-    void NextRandomIndexMetadata();
+    void NextRandomIndexPack();
     void TryToFinish();
 
     //Temp
     int128u EssenceContainer_FromPartitionMetadata;
     int64u PartitionMetadata_PreviousPartition;
     int64u PartitionMetadata_FooterPartition;
-    int64u RandomIndexMetadatas_MaxOffset;
+    int64u RandomIndexPacks_MaxOffset;
     mxftimecode MxfTimeCodeForDelay;
     mxftimecode MxfTimeCodeMaterial;
     float64 DTS_Delay; //In seconds
