@@ -1,20 +1,9 @@
-// File_Wm - Info for Windows Media files
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Elements part
@@ -53,7 +42,7 @@
 #endif
 #if MEDIAINFO_DEMUX
     #include "MediaInfo/MediaInfo_Config_MediaInfo.h"
-    #include "base64.h"
+    #include "ThirdParty/base64/base64.h"
 #endif //MEDIAINFO_DEMUX
 #include "ZenLib/Utils.h"
 using namespace ZenLib;
@@ -66,17 +55,17 @@ namespace MediaInfoLib
 // Constants
 //***************************************************************************
 
-const char* Wm_CodecList_Kind(int32u Kind)
+static const char* Wm_CodecList_Kind(int32u Kind)
 {
     switch (Kind)
     {
         case 0x01 : return "Video";
         case 0x02 : return "Audio";
-        default   : return "Unknown";
+        default   : return "";
     }
 }
 
-const char* Wm_BannerImageData_Type(int32u Type)
+static const char* Wm_BannerImageData_Type(int32u Type)
 {
     switch (Type)
     {
@@ -84,7 +73,7 @@ const char* Wm_BannerImageData_Type(int32u Type)
         case 0x01 : return "Bitmap";
         case 0x02 : return "JPEG";
         case 0x03 : return "GIF";
-        default   : return "Unknown";
+        default   : return "";
     }
 }
 
@@ -145,7 +134,7 @@ namespace Elements
     UUID(Mutex_Bitrate,                                         D6E22A01, 35DA, 11D1, 9034, 00A0C90349BE);
 }
 
-const char* Wm_StreamType(int128u Kind)
+static const char* Wm_StreamType(const int128u& Kind)
 {
     switch (Kind.hi)
     {
@@ -156,17 +145,17 @@ const char* Wm_StreamType(int128u Kind)
         case Elements::Header_StreamProperties_DegradableJPEG : return "Degradable JPEG";
         case Elements::Header_StreamProperties_FileTransfer :   return "File Transfer";
         case Elements::Header_StreamProperties_Binary :         return "Binary";
-        default :                                               return "Unknown";
+        default :                                               return "";
     }
 }
 
-const char* Wm_ExclusionType(int128u ExclusionType)
+static const char* Wm_ExclusionType(const int128u& ExclusionType)
 {
     switch (ExclusionType.hi)
     {
         case Elements::Header_StreamProperties_Audio :          return "Language";
         case Elements::Header_StreamProperties_Video :          return "Bitrate";
-        default :                                               return "Unknown";
+        default :                                               return "";
     }
 }
 
@@ -331,10 +320,11 @@ void File_Wm::Header_StreamProperties ()
         Skip_XX(ErrorCorrectionTypeLength,                      "Error Correction Data");
 
     //Filling
-    Stream[Stream_Number].StreamKind=StreamKind_Last;
-    Stream[Stream_Number].StreamPos=StreamPos_Last;
-    Stream[Stream_Number].Info["ID"].From_Number(Stream_Number);
-    Stream[Stream_Number].Info["StreamOrder"].From_Number(Header_StreamProperties_StreamOrder);
+    stream& StreamItem = Stream[Stream_Number];
+    StreamItem.StreamKind=StreamKind_Last;
+    StreamItem.StreamPos=StreamPos_Last;
+    StreamItem.Info["ID"].From_Number(Stream_Number);
+    StreamItem.Info["StreamOrder"].From_Number(Header_StreamProperties_StreamOrder);
     Header_StreamProperties_StreamOrder++;
 }
 
@@ -373,9 +363,11 @@ void File_Wm::Header_StreamProperties_Audio ()
         #if defined(MEDIAINFO_MPEGA_YES)
         else if (MediaInfoLib::Config.CodecID_Get(Stream_Audio, InfoCodecID_Format_Riff, Ztring::ToZtring(CodecID, 16))==__T("MPEG Audio"))
         {
-            Stream[Stream_Number].Parser=new File_Mpega;
-            ((File_Mpega*)Stream[Stream_Number].Parser)->Frame_Count_Valid=8;
-            Stream[Stream_Number].Parser->ShouldContinueParsing=true;
+            stream& StreamItem = Stream[Stream_Number];
+            File_Mpega* Parser = new File_Mpega;
+            StreamItem.Parser= Parser;
+            Parser->Frame_Count_Valid=8;
+            StreamItem.Parser->ShouldContinueParsing=true;
         }
         #endif
         Open_Buffer_Init(Stream[Stream_Number].Parser);
@@ -416,6 +408,7 @@ void File_Wm::Header_StreamProperties_Audio_WMA ()
                                 std::string Data_Raw((const char*)(Buffer+Buffer_Offset+Element_Offset), (size_t)10);//Element_Size-(Element_Offset));
                                 std::string Data_Base64(Base64::encode(Data_Raw));
                                 Fill(Stream_Audio, StreamPos_Last, "Demux_InitBytes", Data_Base64);
+                                Fill_SetOptions(Stream_Audio, StreamPos_Last, "Demux_InitBytes", "N NT");
                                 }
                                 break;
                     default :   ;
@@ -497,14 +490,16 @@ void File_Wm::Header_StreamProperties_Video ()
     #if defined(MEDIAINFO_VC1_YES)
     else if (MediaInfoLib::Config.CodecID_Get(Stream_Video, InfoCodecID_Format_Riff, Ztring().From_CC4(Compression), InfoCodecID_Format)==__T("VC-1"))
     {
-        Stream[Stream_Number].Parser=new File_Vc1;
+        stream& StreamItem = Stream[Stream_Number];
+        File_Vc1* Parser = new File_Vc1;
+        StreamItem.Parser= Parser;
         if (Compression==CC4("WMV3"))
         {
-            ((File_Vc1*)Stream[Stream_Number].Parser)->From_WMV3=true;
-            ((File_Vc1*)Stream[Stream_Number].Parser)->MustSynchronize=false;
+            Parser->From_WMV3=true;
+            Parser->MustSynchronize=false;
         }
-        ((File_Vc1*)Stream[Stream_Number].Parser)->FrameIsAlwaysComplete=true; //Warning: this is not always the case, see data parsing
-        Open_Buffer_Init(Stream[Stream_Number].Parser);
+        Parser->FrameIsAlwaysComplete=true; //Warning: this is not always the case, see data parsing
+        Open_Buffer_Init(StreamItem.Parser);
         if (Data_Size>40)
         {
 
@@ -522,23 +517,24 @@ void File_Wm::Header_StreamProperties_Video ()
                                 std::string Data_Raw((const char*)(Buffer+(size_t)Element_Offset), (size_t)(Data_Size-40));
                                 std::string Data_Base64(Base64::encode(Data_Raw));
                                 Fill(Stream_Video, StreamPos_Last, "Demux_InitBytes", Data_Base64);
+                                Fill_SetOptions(Stream_Video, StreamPos_Last, "Demux_InitBytes", "N NT");
                                 }
                                 break;
                     default :   ;
                 }
             #endif //MEDIAINFO_DEMUX
-
-            Open_Buffer_Continue(Stream[Stream_Number].Parser, (size_t)(Data_Size-40));
-            if (Stream[Stream_Number].Parser->Status[IsFinished])
+            stream& StreamItem = Stream[Stream_Number];
+            Open_Buffer_Continue(StreamItem.Parser, (size_t)(Data_Size-40));
+            if (StreamItem.Parser->Status[IsFinished])
             {
-                Finish(Stream[Stream_Number].Parser);
-                Merge(*Stream[Stream_Number].Parser, Stream_Video, 0, StreamPos_Last);
-                delete Stream[Stream_Number].Parser; Stream[Stream_Number].Parser=NULL;
+                Finish(StreamItem.Parser);
+                Merge(*StreamItem.Parser, Stream_Video, 0, StreamPos_Last);
+                delete StreamItem.Parser; StreamItem.Parser=NULL;
             }
             else
             {
-                ((File_Vc1*)Stream[Stream_Number].Parser)->Only_0D=true;
-                ((File_Vc1*)Stream[Stream_Number].Parser)->MustSynchronize=false;
+                ((File_Vc1*)StreamItem.Parser)->Only_0D=true;
+                ((File_Vc1*)StreamItem.Parser)->MustSynchronize=false;
             }
         }
     }
@@ -546,9 +542,11 @@ void File_Wm::Header_StreamProperties_Video ()
     #if defined(MEDIAINFO_MPEGV_YES)
     else if (MediaInfoLib::Config.Codec_Get(Ztring().From_CC4(Compression), InfoCodec_KindofCodec).find(__T("MPEG-2"))==0)
     {
-        Stream[Stream_Number].Parser=new File_Mpegv;
-        ((File_Mpegv*)Stream[Stream_Number].Parser)->Frame_Count_Valid=30; //For searching Pulldown
-        Open_Buffer_Init(Stream[Stream_Number].Parser);
+        stream& StreamItem = Stream[Stream_Number];
+        File_Mpegv* Parser = new File_Mpegv;
+        StreamItem.Parser  = Parser;
+        Parser->Frame_Count_Valid=30; //For searching Pulldown
+        Open_Buffer_Init(StreamItem.Parser);
     }
     #endif
     else if (Data_Size>40) //TODO: see "The Mummy_e"
@@ -708,9 +706,10 @@ void File_Wm::Header_HeaderExtension_ExtendedStreamProperties()
     }
 
     //Filling
-    Stream[StreamNumber].LanguageID=LanguageID;
-    Stream[StreamNumber].AverageBitRate=DataBitrate;
-    Stream[StreamNumber].AverageTimePerFrame=AverageTimePerFrame;
+    stream& StreamItem = Stream[StreamNumber];
+    StreamItem.LanguageID=LanguageID;
+    StreamItem.AverageBitRate=DataBitrate;
+    StreamItem.AverageTimePerFrame=AverageTimePerFrame;
 }
 
 //---------------------------------------------------------------------------
@@ -884,12 +883,16 @@ void File_Wm::Header_HeaderExtension_IndexParameters()
 //---------------------------------------------------------------------------
 void File_Wm::Header_HeaderExtension_MediaIndexParameters()
 {
+    Header_HeaderExtension_IndexParameters();
+
     Element_Name("MediaIndex Parameters");
 }
 
 //---------------------------------------------------------------------------
 void File_Wm::Header_HeaderExtension_TimecodeIndexParameters()
 {
+    Header_HeaderExtension_IndexParameters();
+
     Element_Name("Timecode Index Parameters");
 }
 
@@ -1253,8 +1256,9 @@ void File_Wm::Header_StreamBitRate()
         Element_End0();
 
         //Filling
-        if (Stream[StreamNumber].AverageBitRate==0) //Prefere Average bitrate of Extended Stream Properties if present
-            Stream[StreamNumber].AverageBitRate=AverageBitRate;
+        stream& StreamItem = Stream[StreamNumber];
+        if (StreamItem.AverageBitRate==0) //Prefere Average bitrate of Extended Stream Properties if present
+            StreamItem.AverageBitRate=AverageBitRate;
     }
 }
 
@@ -1496,14 +1500,7 @@ void File_Wm::Data_Packet()
                 std::map<int16u, stream>::iterator Strea=Stream.find(Stream_Number);
                 if (Strea!=Stream.end() && Strea->second.StreamKind==Stream_Video)
                 {
-                    if (Strea->second.PresentationTime_Old==0)
-                        Strea->second.PresentationTime_Old=FileProperties_Preroll;
-                    if (PresentationTime!=Strea->second.PresentationTime_Old)
-                    {
-                        Strea->second.PresentationTime_Deltas[PresentationTime-Strea->second.PresentationTime_Old]++;
-                        Strea->second.PresentationTime_Old=PresentationTime;
-                        Strea->second.PresentationTime_Count++;
-                    }
+                    Strea->second.PresentationTimes.insert(PresentationTime);
                 }
             }
             else if (ReplicatedDataLength==1)
@@ -1532,66 +1529,67 @@ void File_Wm::Data_Packet()
         else
         {
             Trusted_IsNot("Padding size problem");
-            return; //Problem
         }
         if (Element_Offset+PayloadLength+Data_Parse_Padding>Element_Size)
         {
             Trusted_IsNot("Payload Length problem");
-            return; //problem
-        }
-
-        //Demux
-        Element_Code=Stream_Number;
-        Demux(Buffer+(size_t)Element_Offset, (size_t)PayloadLength, ContentType_MainStream);
-
-        //Analyzing
-        if (Stream[Stream_Number].Parser && Stream[Stream_Number].SearchingPayload)
-        {
-            //Handling of spanned on multiple chunks
-            #if defined(MEDIAINFO_VC1_YES)
-                bool FrameIsAlwaysComplete=true;
-            #endif
-            if (PayloadLength!=SizeOfMediaObject)
-            {
-                if (SizeOfMediaObject_BytesAlreadyParsed==0)
-                    SizeOfMediaObject_BytesAlreadyParsed=SizeOfMediaObject-PayloadLength;
-                else
-                    SizeOfMediaObject_BytesAlreadyParsed-=PayloadLength;
-                if (SizeOfMediaObject_BytesAlreadyParsed==0)
-                    Element_Show_Count++;
-                #if defined(MEDIAINFO_VC1_YES)
-                else
-                    FrameIsAlwaysComplete=false;
-                #endif
-            }
-            else
-                Element_Show_Count++;
-
-            //Codec specific
-            #if defined(MEDIAINFO_VC1_YES)
-            if (Retrieve(Stream[Stream_Number].StreamKind, Stream[Stream_Number].StreamPos, Fill_Parameter(Stream[Stream_Number].StreamKind, Generic_Format))==__T("VC-1"))
-                ((File_Vc1*)Stream[Stream_Number].Parser)->FrameIsAlwaysComplete=FrameIsAlwaysComplete;
-            #endif
-
-            Open_Buffer_Continue(Stream[Stream_Number].Parser, (size_t)PayloadLength);
-            if (Stream[Stream_Number].Parser->Status[IsFinished]
-             || (Stream[Stream_Number].PresentationTime_Count>=300 && MediaInfoLib::Config.ParseSpeed_Get()<1))
-            {
-                Stream[Stream_Number].Parser->Open_Buffer_Unsynch();
-                Stream[Stream_Number].SearchingPayload=false;
-                Streams_Count--;
-            }
-
-            Element_Show();
         }
         else
         {
-            Skip_XX(PayloadLength,                              "Data");
-            if (Stream[Stream_Number].SearchingPayload
-             && (Stream[Stream_Number].StreamKind==Stream_Video && Stream[Stream_Number].PresentationTime_Count>=300))
+            //Demux
+            Element_Code=Stream_Number;
+            Demux(Buffer+(size_t)Element_Offset, (size_t)PayloadLength, ContentType_MainStream);
+
+            //Analyzing
+            stream& StreamItem = Stream[Stream_Number];
+            if (StreamItem.Parser && StreamItem.SearchingPayload)
             {
-                Stream[Stream_Number].SearchingPayload=false;
-                Streams_Count--;
+                //Handling of spanned on multiple chunks
+                #if defined(MEDIAINFO_VC1_YES)
+                    bool FrameIsAlwaysComplete=true;
+                #endif
+                if (PayloadLength!=SizeOfMediaObject)
+                {
+                    if (SizeOfMediaObject_BytesAlreadyParsed==0)
+                        SizeOfMediaObject_BytesAlreadyParsed=SizeOfMediaObject-PayloadLength;
+                    else
+                        SizeOfMediaObject_BytesAlreadyParsed-=PayloadLength;
+                    if (SizeOfMediaObject_BytesAlreadyParsed==0)
+                        Element_Show_Count++;
+                    #if defined(MEDIAINFO_VC1_YES)
+                    else
+                        FrameIsAlwaysComplete=false;
+                    #endif
+                }
+                else
+                    Element_Show_Count++;
+
+                //Codec specific
+                #if defined(MEDIAINFO_VC1_YES)
+                if (Retrieve(StreamItem.StreamKind, StreamItem.StreamPos, Fill_Parameter(StreamItem.StreamKind, Generic_Format))==__T("VC-1"))
+                    ((File_Vc1*)StreamItem.Parser)->FrameIsAlwaysComplete=FrameIsAlwaysComplete;
+                #endif
+
+                Open_Buffer_Continue(StreamItem.Parser, (size_t)PayloadLength);
+                if (StreamItem.Parser->Status[IsFinished]
+                 || (StreamItem.PresentationTimes.size()>=300 && MediaInfoLib::Config.ParseSpeed_Get()<1))
+                {
+                    StreamItem.Parser->Open_Buffer_Unsynch();
+                    StreamItem.SearchingPayload=false;
+                    Streams_Count--;
+                }
+
+                Element_Show();
+            }
+            else
+            {
+                Skip_XX(PayloadLength,                              "Data");
+                if (StreamItem.SearchingPayload
+                 && (StreamItem.StreamKind==Stream_Video && StreamItem.PresentationTimes.size()>=300))
+                {
+                    StreamItem.SearchingPayload=false;
+                    Streams_Count--;
+                }
             }
         }
         Element_End0();
@@ -1616,20 +1614,21 @@ void File_Wm::Data_Packet_ReplicatedData(int32u Size)
 {
     Element_Begin1("Replicated Data");
     int64u Element_Offset_Final=Element_Offset+Size;
-    for (size_t Pos=0; Pos<Stream[Stream_Number].Payload_Extension_Systems.size(); Pos++)
+    stream& StreamItem = Stream[Stream_Number];
+    for (size_t Pos=0; Pos<StreamItem.Payload_Extension_Systems.size(); Pos++)
     {
         Element_Begin0();
-        switch (Stream[Stream_Number].Payload_Extension_Systems[Pos].ID.hi)
+        switch (StreamItem.Payload_Extension_Systems[Pos].ID.hi)
         {
             case Elements::Payload_Extension_System_TimeStamp :     Data_Packet_ReplicatedData_TimeStamp(); break;
             default :                                               //Not enough info to validate this algorithm
-                                                                    //if (Stream[Stream_Number].Payload_Extension_Systems[Pos].Size!=(int16u)-1)
+                                                                    //if (StreamItem.Payload_Extension_Systems[Pos].Size!=(int16u)-1)
                                                                     //{
                                                                     //    Element_Name("Unknown");
-                                                                    //    Skip_XX(Stream[Stream_Number].Payload_Extension_Systems[Pos].Size, "Unknown");
+                                                                    //    Skip_XX(StreamItem.Payload_Extension_Systems[Pos].Size, "Unknown");
                                                                     //}
                                                                     //else
-                                                                        Pos=Stream[Stream_Number].Payload_Extension_Systems.size(); //Disabling the rest, all is unknown
+                                                                        Pos=StreamItem.Payload_Extension_Systems.size(); //Disabling the rest, all is unknown
         }
         Element_End0();
     }
@@ -1665,9 +1664,9 @@ void File_Wm::Data_Packet_ReplicatedData_TimeStamp()
     Skip_L4(                                                    "Unknown");
     Skip_L4(                                                    "Unknown");
     Skip_L4(                                                    "Unknown");
-
-    if (Stream[Stream_Number].TimeCode_First==(int64u)-1 && TS0!=(int64u)-1)
-        Stream[Stream_Number].TimeCode_First=TS0/10000;
+    stream& StreamItem = Stream[Stream_Number];
+    if (StreamItem.TimeCode_First==(int64u)-1 && TS0!=(int64u)-1)
+        StreamItem.TimeCode_First=TS0/10000;
 }
 
 //---------------------------------------------------------------------------
@@ -1745,7 +1744,85 @@ void File_Wm::MediaIndex()
 //---------------------------------------------------------------------------
 void File_Wm::TimecodeIndex()
 {
-    Element_Name("TimecodeIndex");
+    Element_Name("Timecode Index");
+
+    //Parsing
+    int32u TimeCode_First=(int32u)-1;
+    int32u IndexBlocksCount;
+    int16u IndexSpecifiersCount;
+    Skip_L4(                                                    "Reserved");
+    Get_L2 (IndexSpecifiersCount,                               "Index Specifiers Count");
+    Get_L4 (IndexBlocksCount,                                   "Index Blocks Count");
+    Element_Begin1("Index Specifiers");
+        for (int16u Pos=0; Pos<IndexSpecifiersCount; ++Pos)
+        {
+            Element_Begin1("Index Specifier");
+            Skip_L2(                                                "Stream Number");
+            Info_L2(IndexType,                                      "Index Type");
+            Element_Info1(IndexType);
+            Element_End0();
+        }
+    Element_End0();
+    Element_Begin1("Index Blocks");
+        for (int16u Pos=0; Pos<IndexBlocksCount; ++Pos)
+        {
+            Element_Begin1("Index Block");
+            int32u IndexEntryCount;
+            Get_L4 (IndexEntryCount,                                "Index Entry Count");
+            Skip_L2(                                                "Timecode Range");
+            Element_Begin1("Block Positions");
+                for (int16u Pos=0; Pos<IndexSpecifiersCount; ++Pos)
+                    Skip_L8(                                        "Block Position");
+            Element_End0();
+            Element_Begin1("Index Entries");
+                for (int32u Pos=0; Pos<IndexEntryCount; ++Pos)
+                {
+                    Element_Begin1("Index Entry");
+                    if (TimeCode_First==(int32u)-1)
+                        Get_L4 (TimeCode_First,                     "Timecode");
+                    else
+                        Skip_L4(                                    "Timecode");
+                    for (int16u Pos=0; Pos<IndexSpecifiersCount; ++Pos)
+                        Skip_L4(                                    "Offsets");
+                    Element_End0();
+                }
+            Element_End0();
+            Element_End0();
+        }
+    Element_End0();
+
+    FILLING_BEGIN();
+        Stream_Prepare(Stream_Other);
+        Fill(Stream_Other, StreamPos_Last, Other_Type, "Time code");
+        Fill(Stream_Other, StreamPos_Last, Other_Format, "WM TC");
+        if (TimeCode_First!=(int32u)-1)
+        {
+            int8u H1= TimeCode_First>>28;
+            int8u H2=(TimeCode_First>>24)&0xF;
+            int8u M1=(TimeCode_First>>20)&0xF;
+            int8u M2=(TimeCode_First>>16)&0xF;
+            int8u S1=(TimeCode_First>>12)&0xF;
+            int8u S2=(TimeCode_First>> 8)&0xF;
+            int8u F1=(TimeCode_First>> 4)&0xF;
+            int8u F2= TimeCode_First     &0xF;
+            if (H1<10 && H2<10 && M1<10 && M2<10 && S1<10 && S2<10 && F1<10 && F2<10)
+            {
+                string TC;
+                TC+='0'+H1;
+                TC+='0'+H2;
+                TC+=':';
+                TC+='0'+M1;
+                TC+='0'+M2;
+                TC+=':';
+                TC+='0'+S1;
+                TC+='0'+S2;
+                TC+=':';
+                TC+='0'+F1;
+                TC+='0'+F2;
+                Fill(Stream_Other, StreamPos_Last, Other_TimeCode_FirstFrame, TC.c_str());
+            }
+        }
+    FILLING_END();
 }
 
 //***************************************************************************
