@@ -113,6 +113,12 @@
     #if !defined (MEDIAINFO_MD5_NO) && !defined (MEDIAINFO_MD5_YES)
         #define MEDIAINFO_MD5_NO
     #endif
+    #if !defined (MEDIAINFO_SHA1_NO) && !defined (MEDIAINFO_SHA1_YES)
+        #define MEDIAINFO_SHA1_NO
+    #endif
+    #if !defined (MEDIAINFO_SHA2_NO) && !defined (MEDIAINFO_SHA2_YES)
+        #define MEDIAINFO_SHA2_NO
+    #endif
     #if !defined (MEDIAINFO_AES_NO) && !defined (MEDIAINFO_AES_YES)
         #define MEDIAINFO_AES_NO
     #endif
@@ -133,6 +139,19 @@
         #define MEDIAINFO_TRACE 1
     #endif
 #endif
+#if !defined(MEDIAINFO_TRACE_FFV1CONTENT)
+    #if defined(MEDIAINFO_TRACE_FFV1CONTENT_NO) && defined(MEDIAINFO_TRACE_FFV1CONTENT_YES)
+        #undef MEDIAINFO_TRACE_FFV1CONTENT_NO //MEDIAINFO_TRACE_FFV1CONTENT_YES has priority
+    #endif
+    #if defined(MEDIAINFO_TRACE_FFV1CONTENT_YES)
+        #define MEDIAINFO_TRACE_FFV1CONTENT 1
+    #else
+        #define MEDIAINFO_TRACE_FFV1CONTENT 0
+    #endif
+#endif
+#if MEDIAINFO_TRACE_FFV1CONTENT && !MEDIAINFO_TRACE
+    #define MEDIAINFO_TRACE_FFV1CONTENT 0 //No trace if MEDIAINFO_TRACE is 0
+#endif
 #if !defined(MEDIAINFO_FILTER)
     #if defined(MEDIAINFO_FILTER_NO) && defined(MEDIAINFO_FILTER_YES)
         #undef MEDIAINFO_FILTER_NO //MEDIAINFO_FILTER_YES has priority
@@ -233,6 +252,26 @@
         #define MEDIAINFO_MD5 1
     #endif
 #endif
+#if !defined(MEDIAINFO_SHA1)
+    #if defined(MEDIAINFO_SHA1_NO) && defined(MEDIAINFO_SHA1_YES)
+        #undef MEDIAINFO_SHA1_NO //MEDIAINFO_SHA1_YES has priority
+    #endif
+    #if defined(MEDIAINFO_SHA1_NO)
+        #define MEDIAINFO_SHA1 0
+    #else
+        #define MEDIAINFO_SHA1 1
+    #endif
+#endif
+#if !defined(MEDIAINFO_SHA2)
+    #if defined(MEDIAINFO_SHA2_NO) && defined(MEDIAINFO_SHA2_YES)
+        #undef MEDIAINFO_SHA2_NO //MEDIAINFO_SHA2_YES has priority
+    #endif
+    #if defined(MEDIAINFO_SHA2_NO)
+        #define MEDIAINFO_SHA2 0
+    #else
+        #define MEDIAINFO_SHA2 1
+    #endif
+#endif
 #if !defined(MEDIAINFO_DEMUX)
     #if !defined(MEDIAINFO_DEMUX_NO) && !defined(MEDIAINFO_DEMUX_YES) && !MEDIAINFO_EVENTS
         #define MEDIAINFO_DEMUX_NO //MEDIAINFO_DEMUX is disabled by default if MEDIAINFO_EVENTS is set to 0
@@ -259,6 +298,20 @@
         #define MEDIAINFO_IBI 1
     #endif
 #endif
+#if !defined(MEDIAINFO_IBIUSAGE)
+    #if defined(MEDIAINFO_IBIUSAGE_NO) && defined(MEDIAINFO_IBIUSAGE_YES)
+        #undef MEDIAINFO_IBIUSAGE_NO //MEDIAINFO_IBIUSAGE_YES has priority
+    #endif
+    #if defined(MEDIAINFO_IBIUSAGE_NO)
+        #define MEDIAINFO_IBIUSAGE 0
+    #else
+        #if MEDIAINFO_ADVANCED2
+            #define MEDIAINFO_IBIUSAGE 1
+        #else //MEDIAINFO_ADVANCED2
+            #define MEDIAINFO_IBIUSAGE 0
+        #endif //MEDIAINFO_ADVANCED2
+    #endif
+#endif
 #if !defined(MEDIAINFO_READTHREAD)
     #if defined(MEDIAINFO_READTHREAD_NO) && defined(MEDIAINFO_READTHREAD_YES)
         #undef MEDIAINFO_READTHREAD_NO //MEDIAINFO_READTHREAD_YES has priority
@@ -269,6 +322,20 @@
         #define MEDIAINFO_READTHREAD 1
     #endif
 #endif
+#if !defined(MEDIAINFO_FIXITY)
+    #if defined(MEDIAINFO_FIXITY_NO) && defined(MEDIAINFO_FIXITY_YES)
+        #undef MEDIAINFO_FIXITY_NO //MEDIAINFO_FIXITY_YES has priority
+    #endif
+    #if defined(MEDIAINFO_FIXITY_NO)
+        #define MEDIAINFO_FIXITY 0
+    #else
+        #if MEDIAINFO_ADVANCED
+            #define MEDIAINFO_FIXITY 1
+        #else //MEDIAINFO_ADVANCED
+            #define MEDIAINFO_FIXITY 0
+        #endif //MEDIAINFO_ADVANCED
+    #endif
+#endif
 
 //***************************************************************************
 // Precise configuration
@@ -311,6 +378,9 @@
 #if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_EBUCORE_NO) && !defined(MEDIAINFO_EBUCORE_YES)
     #define MEDIAINFO_EBUCORE_YES
 #endif
+#if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_FIMS_NO) && !defined(MEDIAINFO_FIMS_YES)
+    #define MEDIAINFO_FIMS_YES
+#endif
 #if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_MPEG7_NO) && !defined(MEDIAINFO_MPEG7_YES)
     #define MEDIAINFO_MPEG7_YES
 #endif
@@ -467,6 +537,9 @@
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_UMF_NO) && !defined(MEDIAINFO_UMF_YES)
     #define MEDIAINFO_UMF_YES
 #endif
+#if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_VBI_NO) && !defined(MEDIAINFO_VBI_YES)
+    #define MEDIAINFO_VBI_YES
+#endif
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_WM_NO) && !defined(MEDIAINFO_WM_YES)
     #define MEDIAINFO_WM_YES
 #endif
@@ -575,6 +648,9 @@
 #if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_AU_NO) && !defined(MEDIAINFO_AU_YES)
     #define MEDIAINFO_AU_YES
 #endif
+#if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_CAF_NO) && !defined(MEDIAINFO_CAF_YES)
+    #define MEDIAINFO_CAF_YES
+#endif
 #if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_CELT_NO) && !defined(MEDIAINFO_CELT_YES)
     #define MEDIAINFO_CELT_YES
 #endif
@@ -731,6 +807,9 @@
 #if !defined(MEDIAINFO_IMAGE_NO) && !defined(MEDIAINFO_BMP_NO) && !defined(MEDIAINFO_BMP_YES)
     #define MEDIAINFO_BMP_YES
 #endif
+#if !defined(MEDIAINFO_IMAGE_NO) && !defined(MEDIAINFO_BPG_NO) && !defined(MEDIAINFO_BPG_YES)
+    #define MEDIAINFO_BPG_YES
+#endif
 #if !defined(MEDIAINFO_IMAGE_NO) && !defined(MEDIAINFO_DDS_NO) && !defined(MEDIAINFO_DDS_YES)
     #define MEDIAINFO_DDS_YES
 #endif
