@@ -558,14 +558,14 @@ void File_Mpeg4v::Streams_Fill()
         if (user_data_start_SNC_Data[Pos][0]==__T("AlmEvent") && user_data_start_SNC_Data[Pos][1].size()==16)
             Fill(Stream_Video, 0, "Alarm event", user_data_start_SNC_Data[Pos][1]);
     }
-    if (video_object_layer_start_IsParsed && shape!=2 && !complexity_estimation_disable)
+    if (!(profile_and_level_indication >= B8(11100001) && profile_and_level_indication <= B8(11101000)) && video_object_layer_start_IsParsed && shape!=2 && !complexity_estimation_disable)
     {
         Fill(Stream_Video, 0, "data_partitioned", data_partitioned?"Yes":"No");
-        (*Stream_More)[Stream_Video][0](Ztring().From_Local("data_partitioned"), Info_Options)=__T("N NT");
+        Fill_SetOptions(Stream_Video, 0 ,"data_partitioned", "N NT");
         if (data_partitioned)
         {
             Fill(Stream_Video, 0, "reversible_vlc", reversible_vlc?"Yes":"No");
-            (*Stream_More)[Stream_Video][0](Ztring().From_Local("reversible_vlc"), Info_Options)=__T("N NT");
+            Fill_SetOptions(Stream_Video, 0, "reversible_vlc", "N NT");
         }
     }
 
@@ -1215,7 +1215,7 @@ void File_Mpeg4v::video_object_layer_start()
     }
 
     //Coherancy
-    if (shape!=2 && shape==0 && (object_layer_width==0 || object_layer_height==0 || ((float32)object_layer_width)/object_layer_height<((float32)0.1) || object_layer_width/object_layer_height>10))
+    if (shape==0 && (object_layer_width==0 || object_layer_height==0 || ((float32)object_layer_width)/object_layer_height<((float32)0.1) || object_layer_width/object_layer_height>10))
         Trusted_IsNot("Problem with width and height!");
 
     FILLING_BEGIN();
@@ -1508,7 +1508,7 @@ void File_Mpeg4v::visual_object_start()
     TEST_SB_END();
     }
     Get_S1 ( 4, visual_object_type,                             "visual_object_type"); Param_Info1(Mpeg4v_visual_object_type[visual_object_type]);
-    if (profile_and_level_indication<B8(11100001) || profile_and_level_indication>B8(11101000) && (visual_object_type==1 || visual_object_type==2))
+    if (profile_and_level_indication<B8(11100001) || (profile_and_level_indication>B8(11101000) && (visual_object_type==1 || visual_object_type==2)))
     {
         TEST_SB_SKIP(                                           "video_signal_type");
             Skip_S1(3,                                          "video_format");
@@ -1616,7 +1616,6 @@ void File_Mpeg4v::vop_start()
         Skip_S4(4,                                              "reserved_bits");
         Element_End0();
 
-        bool vop_coded;
         Skip_S2(10,                                             "temporal_reference");
         Skip_S1(2,                                              "vop_structure");
         Get_S1 (2, vop_coding_type,                             "vop_coding_type"); Param_Info1(Mpeg4v_vop_coding_type[vop_coding_type]);
